@@ -220,8 +220,8 @@ bool Aspell::ok() const
 
 string Aspell::dicPath()
 {
-    return path_cat(m_config->getConfDir(), 
-		    string("aspdict.") + m_lang + string(".rws"));
+    string ccdir = m_config->getAspellcacheDir();
+    return path_cat(ccdir, string("aspdict.") + m_lang + string(".rws"));
 }
 
 
