@@ -17,32 +17,29 @@
 #ifndef TEST_RCLCONFIG
 #include "autoconfig.h"
 
-#include <unistd.h>
-#include <fcntl.h>
 #include <stdio.h>
 #include <errno.h>
+#ifndef _WIN32
 #include <langinfo.h>
-#include <limits.h>
 #include <sys/param.h>
-
-#include <algorithm>
-#include <list>
-using std::list;
-
-#include <sys/types.h>
-#include <sys/stat.h>
+#endif
+#include <limits.h>
+#include "safesysstat.h"
+#include "safeunistd.h"
 #ifdef __FreeBSD__
 #include <osreldate.h>
 #endif
 
+#include <algorithm>
+#include <list>
 #include <iostream>
 #include <sstream>
 #include <cstdlib>
 #include <cstring>
-using namespace std;
 
 #include "cstr.h"
 #include "pathut.h"
+#include "rclutil.h"
 #include "rclconfig.h"
 #include "conftree.h"
 #include "debuglog.h"
@@ -51,6 +48,9 @@ using namespace std;
 #include "readfile.h"
 #include "fstreewalk.h"
 #include "cpuconf.h"
+#include "execmd.h"
+
+using namespace std;
 
 typedef pair<int,int> RclPII;
 
@@ -118,7 +118,9 @@ void RclConfig::zeroMe() {
 
 bool RclConfig::isDefaultConfig() const
 {
-    string defaultconf = path_cat(path_canon(path_home()), ".recoll/");
+    string defaultconf = path_cat(path_homedata(),
+                                  path_defaultrecollconfsubdir());
+    path_catslash(defaultconf);
     string specifiedconf = path_canon(m_confdir);
     path_catslash(specifiedconf);
     return !defaultconf.compare(specifiedconf);
@@ -144,14 +146,7 @@ RclConfig::RclConfig(const string *argcnf)
     }
 
     // Compute our data dir name, typically /usr/local/share/recoll
-    const char *cdatadir = getenv("RECOLL_DATADIR");
-    if (cdatadir == 0) {
-	// If not in environment, use the compiled-in constant. 
-	m_datadir = RECOLL_DATADIR;
-    } else {
-	m_datadir = cdatadir;
-    }
-
+    m_datadir = path_pkgdatadir();
     // We only do the automatic configuration creation thing for the default
     // config dir, not if it was specified through -c or RECOLL_CONFDIR
     bool autoconfdir = false;
@@ -170,7 +165,7 @@ RclConfig::RclConfig(const string *argcnf)
 	    m_confdir = path_canon(cp);
 	} else {
 	    autoconfdir = true;
-	    m_confdir = path_cat(path_home(), ".recoll/");
+	    m_confdir = path_cat(path_homedata(), path_defaultrecollconfsubdir());
 	}
     }
 
@@ -178,7 +173,7 @@ RclConfig::RclConfig(const string *argcnf)
     // want to avoid the imperfect test in isDefaultConfig() if we actually know
     // this is the default conf
     if (!autoconfdir && !isDefaultConfig()) {
-	if (access(m_confdir.c_str(), 0) < 0) {
+	if (!path_exists(m_confdir)) {
 	    m_reason = "Explicitly specified configuration "
 		"directory must exist"
 		" (won't be automatically created). Use mkdir first";
@@ -186,7 +181,7 @@ RclConfig::RclConfig(const string *argcnf)
 	}
     }
 
-    if (access(m_confdir.c_str(), 0) < 0) {
+    if (!path_exists(m_confdir)) {
 	if (!initUserConfig()) 
 	    return;
     }
@@ -198,6 +193,7 @@ RclConfig::RclConfig(const string *argcnf)
     // is called from the main thread at once, by constructing a config
     // from recollinit
     if (o_localecharset.empty()) {
+#ifndef _WIN32
 	const char *cp;
 	cp = nl_langinfo(CODESET);
 	// We don't keep US-ASCII. It's better to use a superset
@@ -215,6 +211,9 @@ RclConfig::RclConfig(const string *argcnf)
 	    // Use cp1252 instead of iso-8859-1, it's a superset.
 	    o_localecharset = string(cstr_cp1252);
 	}
+#else
+        o_localecharset = "UTF-8";
+#endif
 	LOGDEB1(("RclConfig::getDefCharset: localecharset [%s]\n",
 		 o_localecharset.c_str()));
     }
@@ -304,8 +303,9 @@ bool RclConfig::updateMainConfig()
     initParamStale(m_conf, mimemap);
 
     setKeyDir(cstr_null);
-    bool nocjk = false;
-    if (getConfParam("nocjk", &nocjk) && nocjk == true) {
+
+    bool bvalue = false;
+    if (getConfParam("nocjk", &bvalue) && bvalue == true) {
 	TextSplit::cjkProcessing(false);
     } else {
 	int ngramlen;
@@ -316,14 +316,18 @@ bool RclConfig::updateMainConfig()
 	}
     }
 
-    bool nonum = false;
-    if (getConfParam("nonumbers", &nonum) && nonum == true) {
+    bvalue = false;
+    if (getConfParam("nonumbers", &bvalue) && bvalue == true) {
 	TextSplit::noNumbers();
     }
 
-    bool fnmpathname = true;
-    if (getConfParam("skippedPathsFnmPathname", &fnmpathname)
-	&& fnmpathname == false) {
+    bvalue = false;
+    if (getConfParam("dehyphenate", &bvalue)) {
+	TextSplit::deHyphenate(bvalue);
+    }
+
+    bvalue = true;
+    if (getConfParam("skippedPathsFnmPathname", &bvalue) && bvalue == false) {
 	FsTreeWalker::setNoFnmPathname();
     }
 
@@ -334,6 +338,9 @@ bool RclConfig::updateMainConfig()
 	m_index_stripchars_init = 1;
     }
 
+    if (getConfParam("cachedir", m_cachedir)) {
+        m_cachedir = path_canon(path_tildexpand(m_cachedir));
+    }
     return true;
 }
 
@@ -617,7 +624,7 @@ bool RclConfig::inStopSuffixes(const string& fni)
 	     it != stoplist.end(); it++) {
 	    STOPSUFFIXES->insert(SfString(stringtolower(*it)));
 	    if (m_maxsufflen < it->length())
-		m_maxsufflen = it->length();
+		m_maxsufflen = int(it->length());
 	}
     }
 
@@ -807,7 +814,7 @@ bool RclConfig::getMissingHelperDesc(string& out) const
 
 void RclConfig::storeMissingHelperDesc(const string &s)
 {
-    string fmiss = path_cat(getConfDir(), "missing");
+    string fmiss = path_cat(getCacheDir(), "missing");
     FILE *fp = fopen(fmiss.c_str(), "w");
     if (fp) {
 	if (s.size() > 0 && fwrite(s.c_str(), s.size(), 1, fp) != 1) {
@@ -850,6 +857,8 @@ bool RclConfig::readFieldsConfig(const string& cnferrloc)
 	    ft.boost = atof(tval.c_str());
 	if (attrs.get("pfxonly", tval))
 	    ft.pfxonly = stringToBool(tval);
+	if (attrs.get("noterms", tval))
+	    ft.noterms = stringToBool(tval);
 	m_fldtotraits[stringtolower(*it)] = ft;
 	LOGDEB2(("readFieldsConfig: [%s] -> [%s] %d %.1f\n", 
 		it->c_str(), ft.pfx.c_str(), ft.wdfinc, ft.boost));
@@ -1124,21 +1133,83 @@ string RclConfig::getMimeIconPath(const string &mtype, const string &apptag)
     return path_cat(iconpath, iconname) + ".png";
 }
 
-string RclConfig::getDbDir() const
+// Return path defined by varname. May be absolute or relative to
+// confdir, with default in confdir
+string RclConfig::getConfdirPath(const char *varname, const char *dflt) const
 {
-    string dbdir;
-    if (!getConfParam("dbdir", dbdir)) {
-	LOGERR(("RclConfig::getDbDir: no db directory in configuration\n"));
+    string result;
+    if (!getConfParam(varname, result)) {
+	result = path_cat(getConfDir(), dflt);
     } else {
-	dbdir = path_tildexpand(dbdir);
+	result = path_tildexpand(result);
 	// If not an absolute path, compute relative to config dir
-	if (dbdir.at(0) != '/') {
-	    LOGDEB1(("Dbdir not abs, catting with confdir\n"));
-	    dbdir = path_cat(getConfDir(), dbdir);
+	if (!path_isabsolute(result)) {
+	    result = path_cat(getConfDir(), result);
 	}
     }
-    LOGDEB1(("RclConfig::getDbDir: dbdir: [%s]\n", dbdir.c_str()));
-    return path_canon(dbdir);
+    return path_canon(result);
+
+}
+
+string RclConfig::getCacheDir() const
+{
+    return m_cachedir.empty() ? getConfDir() : m_cachedir;
+}
+
+// Return path defined by varname. May be absolute or relative to
+// confdir, with default in confdir
+string RclConfig::getCachedirPath(const char *varname, const char *dflt) const
+{
+    string result;
+    if (!getConfParam(varname, result)) {
+	result = path_cat(getCacheDir(), dflt);
+    } else {
+	result = path_tildexpand(result);
+	// If not an absolute path, compute relative to cache dir
+	if (!path_isabsolute(result)) {
+	    result = path_cat(getCacheDir(), result);
+	}
+    }
+    return path_canon(result);
+}
+
+string RclConfig::getDbDir() const
+{
+    return getCachedirPath("dbdir", "xapiandb");
+}
+string RclConfig::getWebcacheDir() const
+{
+    return getCachedirPath("webcachedir", "webcache");
+}
+string RclConfig::getMboxcacheDir() const
+{
+    return getCachedirPath("mboxcachedir", "mboxcache");
+}
+string RclConfig::getAspellcacheDir() const
+{
+    return getCachedirPath("aspellDicDir", "");
+}
+
+string RclConfig::getStopfile() const
+{
+    return getConfdirPath("stoplistfile", "stoplist.txt");
+}
+
+string RclConfig::getSynGroupsFile() const
+{
+    return getConfdirPath("syngroupsfile", "syngroups.txt");
+}
+
+// The index status file is fast changing, so it's possible to put it outside
+// of the config directory (for ssds, not sure this is really useful).
+// To enable being quite xdg-correct we should add a getRundirPath()
+string RclConfig::getIdxStatusFile() const
+{
+    return getCachedirPath("idxstatusfile", "idxstatus.txt");
+}
+string RclConfig::getPidfile() const
+{
+    return path_cat(getCacheDir(), "index.pid");
 }
 
 void RclConfig::urlrewrite(const string& dbdir, string& url) const
@@ -1169,7 +1240,7 @@ void RclConfig::urlrewrite(const string& dbdir, string& url) const
 	    // This call always succeeds because the key comes from getNames()
 	    if (m_ptrans->get(*it, npath, dbdir)) { 
 		path = path.replace(0, it->size(), npath);
-		url = "file://" + path;
+		url = path_pathtofileurl(path);
 	    }
 	    break;
 	}
@@ -1193,32 +1264,6 @@ bool RclConfig::sourceChanged() const
     return false;
 }
 
-string RclConfig::getStopfile() const
-{
-    return path_cat(getConfDir(), "stoplist.txt");
-}
-string RclConfig::getPidfile() const
-{
-    return path_cat(getConfDir(), "index.pid");
-}
-
-// The index status file is fast changing, so it's possible to put it outside
-// of the config directory (for ssds, not sure this is really useful).
-string RclConfig::getIdxStatusFile() const
-{
-    string path;
-    if (!getConfParam("idxstatusfile", path)) {
-	return path_cat(getConfDir(), "idxstatus.txt");
-    } else {
-	path = path_tildexpand(path);
-	// If not an absolute path, compute relative to config dir
-	if (path.at(0) != '/') {
-	    path = path_cat(getConfDir(), path);
-	}
-	return path_canon(path);
-    }
-}
-
 string RclConfig::getWebQueueDir() const
 {
     string webqueuedir;
@@ -1246,6 +1291,9 @@ vector<string> RclConfig::getSkippedPaths() const
     // don't do this.
     skpl.push_back(getDbDir());
     skpl.push_back(getConfDir());
+    if (getCacheDir().compare(getConfDir())) {
+        skpl.push_back(getCacheDir());
+    }
     // And the web queue dir
     skpl.push_back(getWebQueueDir());
     for (vector<string>::iterator it = skpl.begin(); it != skpl.end(); it++) {
@@ -1283,45 +1331,45 @@ vector<string> RclConfig::getDaemSkippedPaths() const
 }
 
 
-// Look up an executable filter.  We look in $RECOLL_FILTERSDIR,
-// filtersdir in config file, then let the system use the PATH
+// Look up an executable filter.  We add $RECOLL_FILTERSDIR,
+// and filtersdir from the config file to the PATH, then use execmd::which()
 string RclConfig::findFilter(const string &icmd) const
 {
     // If the path is absolute, this is it
-    if (icmd[0] == '/')
+    if (path_isabsolute(icmd))
 	return icmd;
 
-    string cmd;
-    const char *cp;
+    const char *cp = getenv("PATH");
+    if (!cp) //??
+        cp = "";
+    string PATH(cp);
 
-    // Filters dir from environment ?
+    // For historical reasons: check in personal config directory
+    PATH = getConfDir() + path_PATHsep() + PATH;
+
+    string temp;
+    // Prepend $datadir/filters
+    temp = path_cat(m_datadir, "filters");
+    PATH = temp + path_PATHsep() + PATH;
+
+    // Prepend possible configuration parameter?
+    if (getConfParam(string("filtersdir"), temp)) {
+        temp = path_tildexpand(temp);
+        PATH = temp + path_PATHsep() + PATH;
+    }
+
+    // Prepend possible environment variable
     if ((cp = getenv("RECOLL_FILTERSDIR"))) {
-	cmd = path_cat(cp, icmd);
-	if (access(cmd.c_str(), X_OK) == 0)
-	    return cmd;
-    } 
-    // Filters dir as configuration parameter?
-    if (getConfParam(string("filtersdir"), cmd)) {
-	cmd = path_cat(cmd, icmd);
-	if (access(cmd.c_str(), X_OK) == 0)
-	    return cmd;
+        PATH = string(cp) + path_PATHsep() + PATH;
     } 
 
-    // Filters dir as datadir subdir. Actually the standard case, but
-    // this is normally the same value found in config file (previous step)
-    cmd = path_cat(m_datadir, "filters");
-    cmd = path_cat(cmd, icmd);
-    if (access(cmd.c_str(), X_OK) == 0)
-	return cmd;
-
-    // Last resort for historical reasons: check in personal config
-    // directory
-    cmd = path_cat(getConfDir(), icmd);
-    if (access(cmd.c_str(), X_OK) == 0)
-	return cmd;
-
-    // Let the shell try to find it...
-    return icmd;
+    string cmd;
+    if (ExecCmd::which(icmd, cmd, PATH.c_str())) {
+        return cmd;
+    } else {
+        // Let the shell try to find it...
+        return icmd;
+    }
 }
 
 /** 
@@ -1346,7 +1394,23 @@ bool RclConfig::getUncompressor(const string &mtype, vector<string>& cmd) const
     if (stringlowercmp("uncompress", *it++)) 
 	return false;
     cmd.clear();
-    cmd.push_back(findFilter(*it++));
+    cmd.push_back(findFilter(*it));
+
+    // Special-case python and perl on windows: we need to also locate the
+    // first argument which is the script name "python somescript.py". 
+    // On Unix, thanks to #!, we usually just run "somescript.py", but need
+    // the same change if we ever want to use the same cmdling as windows
+    if (!stringlowercmp("python", *it) || !stringlowercmp("perl", *it)) {
+        it++;
+        if (tokens.size() < 3) {
+            LOGERR(("getUncpressor: python/perl cmd: no script?. [%s]\n", mtype.c_str()));
+        } else {
+            *it = findFilter(*it);
+        }
+    } else {
+        it++;
+    }
+    
     cmd.insert(cmd.end(), it, tokens.end());
     return true;
 }
@@ -1382,7 +1446,7 @@ bool RclConfig::initUserConfig()
 
     // Use protective 700 mode to create the top configuration
     // directory: documents can be reconstructed from index data.
-    if (access(m_confdir.c_str(), 0) < 0 && 
+    if (!path_exists(m_confdir) && 
 	mkdir(m_confdir.c_str(), 0700) < 0) {
 	m_reason += string("mkdir(") + m_confdir + ") failed: " + 
 	    strerror(errno);
@@ -1391,7 +1455,7 @@ bool RclConfig::initUserConfig()
     string lang = localelang();
     for (int i = 0; i < ncffiles; i++) {
 	string dst = path_cat(m_confdir, string(configfiles[i])); 
-	if (access(dst.c_str(), 0) < 0) {
+	if (!path_exists(dst)) {
 	    FILE *fp = fopen(dst.c_str(), "w");
 	    if (fp) {
 		fprintf(fp, "%s\n", blurb);
@@ -1434,6 +1498,7 @@ void RclConfig::initFrom(const RclConfig& r)
 	return;
     m_reason = r.m_reason;
     m_confdir = r.m_confdir;
+    m_cachedir = r.m_cachedir;
     m_datadir = r.m_datadir;
     m_keydir = r.m_keydir;
     m_cdirs = r.m_cdirs;
