@@ -16,13 +16,14 @@
  */
 #ifndef _RCLCONFIG_H_INCLUDED_
 #define _RCLCONFIG_H_INCLUDED_
+#include "autoconfig.h"
 
 #include <string>
 #include <vector>
 #include <set>
 #include <utility>
 #include <map>
-#include "unordered_defs.h"
+#include UNORDERED_SET_INCLUDE
 
 using std::string;
 using std::vector;
@@ -30,7 +31,6 @@ using std::pair;
 using std::set;
 using std::map;
 
-
 #include "conftree.h"
 #include "smallut.h"
 
@@ -66,9 +66,9 @@ struct FieldTraits {
     int    wdfinc; // Index time term frequency increment (default 1)
     double boost; // Query time boost (default 1.0)
     bool   pfxonly; // Suppress prefix-less indexing
-
+    bool   noterms; // Don't add term to highlight data (e.g.: rclbes)
     FieldTraits() 
-        : wdfinc(1), boost(1.0), pfxonly(false)
+        : wdfinc(1), boost(1.0), pfxonly(false), noterms(false)
         {}
 };
 
@@ -109,6 +109,7 @@ class RclConfig {
      *  constructor it it is the default one (~/.recoll) and it did 
      *  not exist yet. */
     string getConfDir() const {return m_confdir;}
+    string getCacheDir() const;
 
     /** Check if the config files were modified since we read them */
     bool sourceChanged() const;
@@ -171,10 +172,17 @@ class RclConfig {
      * need for other status */
     vector<string> getTopdirs() const;
 
-    /** Get database directory */
+    string getConfdirPath(const char *varname, const char *dflt) const;
+    string getCachedirPath(const char *varname, const char *dflt) const;
+    /** Get database and other directories */
     string getDbDir() const;
+    string getWebcacheDir() const;
+    string getMboxcacheDir() const;
+    string getAspellcacheDir() const;
     /** Get stoplist file name */
     string getStopfile() const;
+    /** Get synonym groups file name */
+    string getSynGroupsFile() const;
     /** Get indexing pid file name */
     string getPidfile() const;
     /** Get indexing status file name */
@@ -330,6 +338,11 @@ class RclConfig {
     int m_ok;
     string m_reason;    // Explanation for bad state
     string m_confdir;   // User directory where the customized files are stored
+    // Normally same as confdir. Set to store all bulk data elsewhere.
+    // Provides defaults top location for dbdir, webcachedir,
+    // mboxcachedir, aspellDictDir, which can still be used to
+    // override.
+    string m_cachedir;  
     string m_datadir;   // Example: /usr/local/share/recoll
     string m_keydir;    // Current directory used for parameter fetches.
     int    m_keydirgen; // To help with knowing when to update computed data.
