@@ -24,8 +24,7 @@
 #include <string>
 #include <algorithm>
 #include <cstring>
-#include "unordered_defs.h"
-using namespace std;
+#include UNORDERED_SET_INCLUDE
 
 #include "textsplit.h"
 #include "debuglog.h"
@@ -33,6 +32,7 @@ using namespace std;
 #include "utf8iter.h"
 #include "uproplist.h"
 
+using namespace std;
 
 /**
  * Splitting a text into words. The code in this file works with utf-8
@@ -214,15 +214,16 @@ bool TextSplit::isCJK(int c)
 bool          TextSplit::o_processCJK = true;
 unsigned int  TextSplit::o_CJKNgramLen = 2;
 bool          TextSplit::o_noNumbers = false;
+bool          TextSplit::o_deHyphenate = false;
 
 // Final term checkpoint: do some checking (the kind which is simpler
 // to do here than in the main loop), then send term to our client.
 inline bool TextSplit::emitterm(bool isspan, string &w, int pos, 
-				int btstart, int btend)
+				size_t btstart, size_t btend)
 {
     LOGDEB2(("TextSplit::emitterm: [%s] pos %d\n", w.c_str(), pos));
 
-    unsigned int l = w.length();
+    int l = int(w.length());
 
 #ifdef TEXTSPLIT_STATS
     // Update word length statistics. Do this before we filter out
@@ -231,7 +232,7 @@ inline bool TextSplit::emitterm(bool isspan, string &w, int pos,
 	m_stats.newsamp(m_wordChars);
 #endif
 
-    if (l > 0 && l < (unsigned)m_maxWordLength) {
+    if (l > 0 && l < m_maxWordLength) {
 	// 1 byte word: we index single ascii letters and digits, but
 	// nothing else. We might want to turn this into a test for a
 	// single utf8 character instead ?
@@ -246,9 +247,9 @@ inline bool TextSplit::emitterm(bool isspan, string &w, int pos,
 	    }
 	}
 	if (pos != m_prevpos || l != m_prevlen) {
-	    bool ret = takeword(w, pos, btstart, btend);
+	    bool ret = takeword(w, pos, int(btstart), int(btend));
 	    m_prevpos = pos;
-	    m_prevlen = w.length();
+	    m_prevlen = int(w.length());
 	    return ret;
 	}
 	LOGDEB2(("TextSplit::emitterm:dup: [%s] pos %d\n", w.c_str(), pos));
@@ -294,7 +295,7 @@ bool TextSplit::span_is_acronym(string *acronym)
 
 // Generate terms from span. Have to take into account the
 // flags: ONLYSPANS, NOSPANS, noNumbers
-bool TextSplit::words_from_span(int bp)
+bool TextSplit::words_from_span(size_t bp)
 {
 #if 0
     cerr << "Span: [" << m_span << "] " << " w_i_s size: " << 
@@ -306,35 +307,44 @@ bool TextSplit::words_from_span(int bp)
     }
     cerr << endl;
 #endif
-    unsigned int spanwords = m_words_in_span.size();
-
-    // Not supposed to happen.
-    if (spanwords == 0 || m_span.size() == 0)
-        return true;
-
+    int spanwords = int(m_words_in_span.size());
     int pos = m_spanpos;
     // Byte position of the span start
-    int spboffs = bp - m_span.size();
+    size_t spboffs = bp - m_span.size();
 
-    for (unsigned int i = 0; 
+    if (o_deHyphenate && spanwords == 2 && 
+	m_span[m_words_in_span[0].second] == '-') {
+	unsigned int s0 = m_words_in_span[0].first;
+	unsigned int l0 = m_words_in_span[0].second - m_words_in_span[0].first;
+	unsigned int s1 = m_words_in_span[1].first;
+	unsigned int l1 = m_words_in_span[1].second - m_words_in_span[1].first;
+	string word = m_span.substr(s0, l0) + m_span.substr(s1, l1);
+	if (l0 && l1) 
+	    emitterm(false, word,
+		     m_spanpos, spboffs, spboffs + m_words_in_span[1].second);
+    }
+
+    for (int i = 0; 
          i < ((m_flags&TXTS_ONLYSPANS) ? 1 : spanwords); 
-         i++, pos++) {
+         i++) {
 
         int deb = m_words_in_span[i].first;
-
-        for (unsigned int j = ((m_flags&TXTS_ONLYSPANS) ? spanwords-1 : i);
+        bool noposinc = m_words_in_span[i].second == deb;
+        for (int j = ((m_flags&TXTS_ONLYSPANS) ? spanwords-1 : i);
              j < ((m_flags&TXTS_NOSPANS) ? i+1 : spanwords);
              j++) {
 
             int fin = m_words_in_span[j].second;
             //cerr << "i " << i << " j " << j << " deb " << deb << 
-            // " fin " << fin << endl;
+            //" fin " << fin << endl;
             if (fin - deb > int(m_span.size()))
                 break;
             string word(m_span.substr(deb, fin-deb));
             if (!emitterm(j != i+1, word, pos, spboffs+deb, spboffs+fin))
                 return false;
         }
+        if (!noposinc)
+            ++pos;
     }
     return true;
 }
@@ -356,11 +366,12 @@ bool TextSplit::words_from_span(int bp)
  * @param spanerase Set if the current span is at its end. Process it.
  * @param bp        The current BYTE position in the stream
  */
-inline bool TextSplit::doemit(bool spanerase, int bp)
+inline bool TextSplit::doemit(bool spanerase, size_t _bp)
 {
+    int bp = int(_bp);
     LOGDEB2(("TextSplit::doemit: sper %d bp %d spp %d spanwords %u wS %d wL %d "
             "inn %d span [%s]\n",
-            spanerase, bp, m_spanpos, m_words_in_span.size(), 
+             spanerase, bp, m_spanpos, m_words_in_span.size(), 
             m_wordStart, m_wordLen, m_inNumber, m_span.c_str()));
 
     if (m_wordLen) {
@@ -397,18 +408,9 @@ inline bool TextSplit::doemit(bool spanerase, int bp)
 	    case '_':
 	    case '\'':
 		m_span.resize(m_span.length()-1);
-                // Trim last word in span word array. Pop it if it
-                // goes to zero. This is not supposed to happen
-                // because it would probably signal a parser bug, but
-                // makes sense anyway
                 if (m_words_in_span.size() &&
-                    m_words_in_span.back().second > m_span.size()) {
-                    m_words_in_span.back().second = m_span.size();
-                    if (m_words_in_span.back().second <=
-                        m_words_in_span.back().first) {
-                        m_words_in_span.pop_back();
-                    }
-                }
+                    m_words_in_span.back().second > int(m_span.size()))
+                    m_words_in_span.back().second = int(m_span.size());
 		if (--bp < 0) 
 		    bp = 0;
 		break;
@@ -418,14 +420,14 @@ inline bool TextSplit::doemit(bool spanerase, int bp)
 	}
     breaktrimloop:
 
-        if (m_words_in_span.size() && !words_from_span(bp)) {
+        if (!words_from_span(bp)) {
             return false;
         }
 	discardspan();
 
     } else {
     
-	m_wordStart = m_span.length();
+	m_wordStart = int(m_span.length());
 
     }
 
@@ -642,8 +644,12 @@ bool TextSplit::text_to_words(const string &in)
                     // Check for number like .1
                     if (isdigit(nextwhat, m_flags)) {
                         m_inNumber = true;
+                        m_wordLen += it.appendchartostring(m_span);
+                    } else {
+                        m_words_in_span.
+                            push_back(pair<int,int>(m_wordStart, m_wordStart));
+                        m_wordStart += it.appendchartostring(m_span);
                     }
-                    m_wordLen += it.appendchartostring(m_span);
                     STATS_INC_WORDCHARS;
                     break;
                 }
@@ -671,16 +677,16 @@ bool TextSplit::text_to_words(const string &in)
 	    }
 	    break;
 
-	case '#': 
+	case '#':  {
+	    int w = whatcc(it[it.getCpos()+1]);
 	    // Keep it only at the beginning of a word (hashtag), 
-            if (m_wordLen == 0) {
+            if (m_wordLen == 0 && isalphanum(w, m_flags)) {
                 m_wordLen += it.appendchartostring(m_span);
                 STATS_INC_WORDCHARS;
                 break;
             }
             // or at the end (special case for c# ...)
 	    if (m_wordLen > 0) {
-		int w = whatcc(it[it.getCpos()+1]);
 		if (w == SPACE || w == '\n' || w == '\r') {
 		    m_wordLen += it.appendchartostring(m_span);
 		    STATS_INC_WORDCHARS;
@@ -688,6 +694,7 @@ bool TextSplit::text_to_words(const string &in)
 		}
 	    }
 	    goto SPACE;
+	}
 	    break;
 
 	case '\n':
@@ -832,16 +839,16 @@ bool TextSplit::cjk_to_words(Utf8Iter *itp, unsigned int *cp)
 	}
 
 	// Take note of byte offset for this character.
-	boffs[nchars-1] = it.getBpos();
+	boffs[nchars-1] = int(it.getBpos());
 
 	// Output all new ngrams: they begin at each existing position
 	// and end after the new character. onlyspans->only output
 	// maximum words, nospans=> single chars
 	if (!(m_flags & TXTS_ONLYSPANS) || nchars == o_CJKNgramLen) {
-	    unsigned int btend = it.getBpos() + it.getBlen();
-	    unsigned int loopbeg = (m_flags & TXTS_NOSPANS) ? nchars-1 : 0;
-	    unsigned int loopend = (m_flags & TXTS_ONLYSPANS) ? 1 : nchars;
-	    for (unsigned int i = loopbeg; i < loopend; i++) {
+	    int btend = int(it.getBpos() + it.getBlen());
+	    int loopbeg = (m_flags & TXTS_NOSPANS) ? nchars-1 : 0;
+	    int loopend = (m_flags & TXTS_ONLYSPANS) ? 1 : nchars;
+	    for (int i = loopbeg; i < loopend; i++) {
 		if (!takeword(it.buffer().substr(boffs[i], 
 						       btend-boffs[i]),
 				m_wordpos - (nchars-i-1), boffs[i], btend)) {
@@ -862,7 +869,7 @@ bool TextSplit::cjk_to_words(Utf8Iter *itp, unsigned int *cp)
     // If onlyspans is set, there may be things to flush in the buffer
     // first
     if ((m_flags & TXTS_ONLYSPANS) && nchars > 0 && nchars != o_CJKNgramLen)  {
-	unsigned int btend = it.getBpos(); // Current char is out
+	int btend = int(it.getBpos()); // Current char is out
 	if (!takeword(it.buffer().substr(boffs[0], btend-boffs[0]),
 			    m_wordpos - nchars,
 			    boffs[0], btend)) {
