@@ -22,10 +22,6 @@
 #include <string>
 #include <vector>
 
-using std::string;
-using std::vector;
-using std::pair;
-
 class Utf8Iter;
 
 /** 
@@ -56,6 +52,13 @@ public:
 	o_noNumbers = true;
     }
 
+    // Given [co-worker] as input, do we also generate [coworker] ?
+    // Set by rclconfig
+    static bool o_deHyphenate;
+    static void deHyphenate(bool on) {
+	o_deHyphenate = on;
+    }
+
     enum Flags {
         // Default: will return spans and words (a_b, a, b)
         TXTS_NONE = 0, 
@@ -77,10 +80,10 @@ public:
     virtual ~TextSplit() {}
 
     /** Split text, emit words and positions. */
-    virtual bool text_to_words(const string &in);
+    virtual bool text_to_words(const std::string &in);
 
     /** Process one output word: to be implemented by the actual user class */
-    virtual bool takeword(const string& term, 
+    virtual bool takeword(const std::string& term, 
 			  int pos,  // term pos
 			  int bts,  // byte offset of first char in term
 			  int bte   // byte offset of first char after term
@@ -96,10 +99,10 @@ public:
     // Static utility functions:
 
     /** Count words in string, as the splitter would generate them */
-    static int countWords(const string &in, Flags flgs = TXTS_ONLYSPANS);
+    static int countWords(const std::string &in, Flags flgs = TXTS_ONLYSPANS);
 
     /** Check if this is visibly not a single block of text */
-    static bool hasVisibleWhite(const string &in);
+    static bool hasVisibleWhite(const std::string &in);
 
     /** Split text span into strings, at white space, allowing for substrings
      * quoted with " . Escaping with \ works as usual inside the quoted areas.
@@ -108,7 +111,7 @@ public:
      * non-utf-8 input (iso-8859 config files work ok). This hopefully
      * handles all Unicode whitespace, but needs correct utf-8 input
      */
-    static bool stringToStrings(const string &s, vector<string> &tokens);
+    static bool stringToStrings(const std::string &s, std::vector<std::string> &tokens);
 
     /** Is char CJK ? */
     static bool isCJK(int c);
@@ -179,9 +182,9 @@ private:
     int           m_maxWordLength;
 
     // Current span. Might be jf.dockes@wanadoo.f
-    string        m_span; 
+    std::string        m_span; 
 
-    vector <pair<unsigned int, unsigned int> > m_words_in_span;
+    std::vector <std::pair<int, int> > m_words_in_span;
 
     // Current word: no punctuation at all in there. Byte offset
     // relative to the current span and byte length
@@ -198,7 +201,7 @@ private:
     // It may happen that our cleanup would result in emitting the
     // same term twice. We try to avoid this
     int           m_prevpos;
-    unsigned int  m_prevlen;
+    int           m_prevlen;
 
 #ifdef TEXTSPLIT_STATS
     // Stats counters. These are processed in TextSplit rather than by a 
@@ -212,11 +215,11 @@ private:
     // This processes cjk text:
     bool cjk_to_words(Utf8Iter *it, unsigned int *cp);
 
-    bool emitterm(bool isspan, string &term, int pos, int bs, int be);
-    bool doemit(bool spanerase, int bp);
+    bool emitterm(bool isspan, std::string &term, int pos, size_t bs,size_t be);
+    bool doemit(bool spanerase, size_t bp);
     void discardspan();
     bool span_is_acronym(std::string *acronym);
-    bool words_from_span(int bp);
+    bool words_from_span(size_t bp);
 };
 
 #endif /* _TEXTSPLIT_H_INCLUDED_ */
