@@ -16,13 +16,14 @@
  */
 #include "autoconfig.h"
 
-#include <unistd.h>
-#include <sys/types.h>
 #include <string.h>
 #include <errno.h>
+#include "safesysstat.h"
+#include "safeunistd.h"
 
 #include "cstr.h"
 #include "pathut.h"
+#include "rclutil.h"
 #include "debuglog.h"
 #include "fstreewalk.h"
 #include "beaglequeue.h"
@@ -43,9 +44,6 @@
 
 using namespace std;
 
-#include <sys/stat.h>
-
-
 // Beagle creates a file named .xxx (where xxx is the name for the main file
 // in the queue), to hold external metadata (http or created by Beagle).
 // This class reads the .xxx, dotfile, and turns it into an Rcl::Doc holder
@@ -261,7 +259,7 @@ bool BeagleQueueIndexer::index()
         return false;
     LOGDEB(("BeagleQueueIndexer::processqueue: [%s]\n", m_queuedir.c_str()));
     m_config->setKeyDir(m_queuedir);
-    if (!makepath(m_queuedir)) {
+    if (!path_makepath(m_queuedir, 0700)) {
 	LOGERR(("BeagleQueueIndexer:: can't create queuedir [%s] errno %d\n", 
 		m_queuedir.c_str(), errno));
 	return false;
@@ -345,7 +343,7 @@ bool BeagleQueueIndexer::indexFiles(list<string>& files)
             it++; continue;
         }
         struct stat st;
-        if (lstat(it->c_str(), &st) != 0) {
+        if (path_fileprops(*it, &st) != 0) {
             LOGERR(("BeagleQueueIndexer::indexfiles: cant stat [%s]\n", 
                     it->c_str()));
             it++; continue;
@@ -404,9 +402,7 @@ BeagleQueueIndexer::processone(const string &path,
         if (dotdoc.fmtime.empty())
             dotdoc.fmtime = ascdate;
 
-        char cbuf[100]; 
-        sprintf(cbuf, "%lld", (long long)stp->st_size);
-        dotdoc.pcbytes = cbuf;
+        dotdoc.pcbytes = lltodecstr(stp->st_size);
 
         // Document signature for up to date checks: none. 
         dotdoc.sig.clear();
@@ -444,9 +440,7 @@ BeagleQueueIndexer::processone(const string &path,
             doc.fmtime = ascdate;
         dotdoc.fmtime = doc.fmtime;
 
-        char cbuf[100]; 
-        sprintf(cbuf, "%lld", (long long)stp->st_size);
-        doc.pcbytes = cbuf;
+        doc.pcbytes = lltodecstr(stp->st_size);
         // Document signature for up to date checks: none. 
         doc.sig.clear();
         doc.url = dotdoc.url;
