@@ -17,10 +17,9 @@
 #include "autoconfig.h"
 
 #include <stdio.h>
-#include <sys/stat.h>
-#include <unistd.h>
 #include <errno.h>
 #include <cstring>
+#include "safesysstat.h"
 
 #include <iostream>
 #include <list>
@@ -29,6 +28,7 @@
 
 #include "cstr.h"
 #include "pathut.h"
+#include "rclutil.h"
 #include "conftree.h"
 #include "rclconfig.h"
 #include "fstreewalk.h"
@@ -40,11 +40,11 @@
 #include "debuglog.h"
 #include "internfile.h"
 #include "smallut.h"
+#include "chrono.h"
 #include "wipedir.h"
 #include "fileudi.h"
 #include "cancelcheck.h"
 #include "rclinit.h"
-#include "execmd.h"
 #include "extrameta.h"
 
 using namespace std;
@@ -146,13 +146,11 @@ FsIndexer::~FsIndexer()
     void *status;
     if (m_haveInternQ) {
 	status = m_iwqueue.setTerminateAndWait();
-	LOGDEB0(("FsIndexer: internfile wrkr status: %ld (1->ok)\n", 
-		 long(status)));
+	LOGDEB0(("FsIndexer: internfile wrkr status: %p (1->ok)\n", status));
     }
     if (m_haveSplitQ) {
 	status = m_dwqueue.setTerminateAndWait();
-	LOGDEB0(("FsIndexer: dbupd worker status: %ld (1->ok)\n", 
-		 long(status)));
+	LOGDEB0(("FsIndexer: dbupd worker status: %p (1->ok)\n", status));
     }
     delete m_stableconfig;
 #endif // IDX_THREADS
@@ -185,7 +183,6 @@ bool FsIndexer::index(int flags)
 #ifdef IDX_THREADS
 	PTMutexLocker locker(m_updater->m_mutex);
 #endif
-	m_updater->status.reset();
 	m_updater->status.dbtotdocs = m_db->docCnt();
     }
 
@@ -243,7 +240,7 @@ bool FsIndexer::index(int flags)
 	}
 	m_config->storeMissingHelperDesc(missing);
     }
-    LOGINFO(("fsindexer index time:  %d mS\n", chron.ms()));
+    LOGINFO(("fsindexer index time:  %d mS\n", chron.millis()));
     return true;
 }
 
@@ -260,7 +257,7 @@ static bool matchesSkipped(const vector<string>& tdl,
     string canonpath = path_canon(path);
     string mpath = canonpath;
     string topdir;
-    while (mpath.length() > 1) {
+    while (!path_isroot(mpath)) { // we assume root not in skipped paths.
         for (vector<string>::const_iterator it = tdl.begin();  
              it != tdl.end(); it++) {
             // the topdirs members are already canonized.
@@ -282,7 +279,7 @@ static bool matchesSkipped(const vector<string>& tdl,
         mpath = path_getfather(mpath);
         // getfather normally returns a path ending with /, canonic
         // paths don't (except for '/' itself).
-        if (!mpath.empty() && mpath[mpath.size()-1] == '/')
+        if (!path_isroot(mpath) && mpath[mpath.size()-1] == '/')
             mpath.erase(mpath.size()-1);
         // should not be necessary, but lets be prudent. If the
         // path did not shorten, something is seriously amiss
@@ -331,7 +328,7 @@ bool FsIndexer::indexFiles(list<string>& files, int flags)
 {
     LOGDEB(("FsIndexer::indexFiles\n"));
     m_noretryfailed = (flags & ConfIndexer::IxFNoRetryFailed) != 0;
-    int ret = false;
+    bool ret = false;
 
     if (!init())
         return false;
@@ -365,10 +362,9 @@ bool FsIndexer::indexFiles(list<string>& files, int flags)
         }
 
 	struct stat stb;
-	int ststat = follow ? stat(it->c_str(), &stb) : 
-	    lstat(it->c_str(), &stb);
+	int ststat = path_fileprops(*it, &stb, follow);
 	if (ststat != 0) {
-	    LOGERR(("FsIndexer::indexFiles: lstat(%s): %s", it->c_str(),
+	    LOGERR(("FsIndexer::indexFiles: (l)stat %s: %s", it->c_str(),
 		    strerror(errno)));
             it++; 
 	    continue;
@@ -491,11 +487,8 @@ void FsIndexer::setlocalfields(const map<string, string>& fields, Rcl::Doc& doc)
 
 void FsIndexer::makesig(const struct stat *stp, string& out)
 {
-    char cbuf[100]; 
-    sprintf(cbuf, "%lld" "%ld", (long long)stp->st_size, 
-            o_uptodate_test_use_mtime ? 
-            (long)stp->st_mtime : (long)stp->st_ctime);
-    out = cbuf;
+    out = lltodecstr(stp->st_size) + 
+        lltodecstr(o_uptodate_test_use_mtime ? stp->st_mtime : stp->st_ctime);
 }
 
 #ifdef IDX_THREADS
@@ -704,7 +697,7 @@ FsIndexer::processonefile(RclConfig *config,
     }
 
     LOGDEB0(("processone: processing: [%s] %s\n", 
-             displayableBytes(stp->st_size).c_str(), fn.c_str()));
+             displayableBytes(off_t(stp->st_size)).c_str(), fn.c_str()));
 
     string utf8fn = compute_utf8fn(config, fn);
 
@@ -773,7 +766,7 @@ FsIndexer::processonefile(RclConfig *config,
 	    if (doc.fmtime.empty())
 		doc.fmtime = ascdate;
 	    if (doc.url.empty())
-		doc.url = cstr_fileu + fn;
+		doc.url = path_pathtofileurl(fn);
 	    const string *fnp = 0;
 	    if (doc.ipath.empty()) {
                 if (!doc.peekmeta(Rcl::Doc::keyfn, &fnp) || fnp->empty())
@@ -782,9 +775,7 @@ FsIndexer::processonefile(RclConfig *config,
             // Set container file name for all docs, top or subdoc
             doc.meta[Rcl::Doc::keytcfn] = utf8fn;
 
-	    char cbuf[100]; 
-	    sprintf(cbuf, "%lld", (long long)stp->st_size);
-	    doc.pcbytes = cbuf;
+	    doc.pcbytes = lltodecstr(stp->st_size);
 	    // Document signature for up to date checks. All subdocs inherit the
 	    // file's.
 	    doc.sig = sig;
@@ -831,8 +822,14 @@ FsIndexer::processonefile(RclConfig *config,
 		if (m_updater->status.dbtotdocs < m_updater->status.docsdone)
 		    m_updater->status.dbtotdocs = m_updater->status.docsdone;
 		m_updater->status.fn = fn;
-		if (!doc.ipath.empty())
+		if (!doc.ipath.empty()) {
 		    m_updater->status.fn += "|" + doc.ipath;
+                } else {
+                    if (fis == FileInterner::FIError) {
+                        ++(m_updater->status.fileerrors);
+                    }
+                    ++(m_updater->status.filesdone);
+                }
 		if (!m_updater->update()) {
 		    return FsTreeWalker::FtwStop;
 		}
@@ -869,12 +866,10 @@ FsIndexer::processonefile(RclConfig *config,
                 fileDoc.meta[Rcl::Doc::keytcfn] = utf8fn;
 	    fileDoc.haschildren = true;
 	    fileDoc.mimetype = mimetype;
-	    fileDoc.url = cstr_fileu + fn;
+	    fileDoc.url = path_pathtofileurl(fn);
 	    if (m_havelocalfields) 
 		setlocalfields(localfields, fileDoc);
-	    char cbuf[100]; 
-	    sprintf(cbuf, "%lld", (long long)stp->st_size);
-	    fileDoc.pcbytes = cbuf;
+	    fileDoc.pcbytes = lltodecstr(stp->st_size);
 	}
 
 	fileDoc.sig = sig;
