@@ -14,13 +14,9 @@
  *   Free Software Foundation, Inc.,
  *   59 Temple Place - Suite 330, Boston, MA  02111-1307, USA.
  */
-#ifdef HAVE_CONFIG_H
 #include "autoconfig.h"
-#endif
 
 #include <stdio.h>
-#include <sys/stat.h>
-#include <unistd.h>
 #include <errno.h>
 
 #include <algorithm>
@@ -29,8 +25,11 @@
 #include "debuglog.h"
 #include "indexer.h"
 #include "fsindexer.h"
+#ifndef DISABLE_WEB_INDEXER
 #include "beaglequeue.h"
+#endif
 #include "mimehandler.h"
+#include "pathut.h"
 
 #ifdef RCL_USE_ASPELL
 #include "rclaspell.h"
@@ -47,7 +46,9 @@ ConfIndexer::ConfIndexer(RclConfig *cnf, DbIxStatusUpdater *updfunc)
 ConfIndexer::~ConfIndexer()
 {
      deleteZ(m_fsindexer);
+#ifndef DISABLE_WEB_INDEXER
      deleteZ(m_beagler);
+#endif
 }
 
 // Determine if this is likely the first time that the user runs
@@ -58,15 +59,12 @@ ConfIndexer::~ConfIndexer()
 bool ConfIndexer::runFirstIndexing()
 {
     // Indexing status file existing and not empty ?
-    struct stat st;
-    if (stat(m_config->getIdxStatusFile().c_str(), &st) == 0 && 
-	st.st_size > 0) {
+    if (path_filesize(m_config->getIdxStatusFile()) > 0) {
 	LOGDEB0(("ConfIndexer::runFirstIndexing: no: status file not empty\n"));
-	exit(1);
 	return false;
     }
     // And only do this if the user has kept the default topdirs (~). 
-    vector<string>tdl = m_config->getTopdirs();
+    vector<string> tdl = m_config->getTopdirs();
     if (tdl.size() != 1 || tdl[0].compare(path_canon(path_tildexpand("~")))) {
 	LOGDEB0(("ConfIndexer::runFirstIndexing: no: not home only\n"));
 	return false;
@@ -111,7 +109,7 @@ bool ConfIndexer::index(bool resetbefore, ixType typestorun, int flags)
             return false;
         }
     }
-
+#ifndef DISABLE_WEB_INDEXER
     if (m_dobeagle && (typestorun & IxTBeagleQueue)) {
         deleteZ(m_beagler);
         m_beagler = new BeagleQueueIndexer(m_config, &m_db, m_updater);
@@ -120,7 +118,7 @@ bool ConfIndexer::index(bool resetbefore, ixType typestorun, int flags)
             return false;
         }
     }
-
+#endif
     if (typestorun == IxTAll) {
         // Get rid of all database entries that don't exist in the
         // filesystem anymore. Only if all *configured* indexers ran.
@@ -177,6 +175,7 @@ bool ConfIndexer::indexFiles(list<string>& ifiles, int flag)
         ret = m_fsindexer->indexFiles(myfiles, flag);
     LOGDEB2(("ConfIndexer::indexFiles: fsindexer returned %d, "
             "%d files remainining\n", ret, myfiles.size()));
+#ifndef DISABLE_WEB_INDEXER
 
     if (m_dobeagle && !myfiles.empty() && !(flag & IxFNoWeb)) {
         if (!m_beagler)
@@ -187,7 +186,7 @@ bool ConfIndexer::indexFiles(list<string>& ifiles, int flag)
             ret = false;
         }
     }
-
+#endif
     // The close would be done in our destructor, but we want status here
     if (!m_db.close()) {
 	LOGERR(("ConfIndexer::index: error closing database in %s\n", 
@@ -259,6 +258,7 @@ bool ConfIndexer::purgeFiles(std::list<string> &files, int flag)
     if (m_fsindexer)
         ret = m_fsindexer->purgeFiles(myfiles);
 
+#ifndef DISABLE_WEB_INDEXER
     if (m_dobeagle && !myfiles.empty() && !(flag & IxFNoWeb)) {
         if (!m_beagler)
             m_beagler = new BeagleQueueIndexer(m_config, &m_db, m_updater);
@@ -268,6 +268,7 @@ bool ConfIndexer::purgeFiles(std::list<string> &files, int flag)
             ret = false;
         }
     }
+#endif
 
     // The close would be done in our destructor, but we want status here
     if (!m_db.close()) {
