@@ -16,11 +16,13 @@
  *   Free Software Foundation, Inc.,
  *   59 Temple Place - Suite 330, Boston, MA  02111-1307, USA.
  */
-#include <unistd.h>
-#include <sys/stat.h>
+#include "autoconfig.h"
+
 #include <errno.h>
 #include <cstdio>
 #include <cstring>
+#include "safesysstat.h"
+#include "safeunistd.h"
 
 #include "debuglog.h"
 #include "rclmon.h"
@@ -298,7 +300,6 @@ bool eraseWatchSubTree(map<int, string>& idtopath, const string& top)
 #include <fam.h>
 #include <sys/select.h>
 #include <setjmp.h>
-#include <unistd.h>
 #include <signal.h>
 
 /** FAM based monitor class. We have to keep a record of FAM watch
@@ -468,7 +469,7 @@ bool RclFAM::getEvent(RclMonEvent& ev, int msecs)
     MONDEB(("RclFAM::getEvent: FAMNextEvent returned\n"));
     
     map<int,string>::const_iterator it;
-    if ((fe.filename[0] != '/') && 
+    if ((!path_isabsolute(fe.filename)) && 
 	(it = m_idtopath.find(fe.fr.reqnum)) != m_idtopath.end()) {
 	ev.m_path = path_cat(it->second, fe.filename);
     } else {
