@@ -46,11 +46,17 @@ void reapXAttrs(const RclConfig* cfg, const string& path,
 		map<string, string>& xfields)
 {
     LOGDEB2(("reapXAttrs: [%s]\n", path.c_str()));
-    
+#ifndef _WIN32
     // Retrieve xattrs names from files and mapping table from config
     vector<string> xnames;
     if (!pxattr::list(path, &xnames)) {
-	LOGERR(("FileInterner::reapXattrs: pxattr::list: errno %d\n", errno));
+        if (errno == ENOTSUP) {
+            LOGDEB(("FileInterner::reapXattrs: pxattr::list: errno %d\n",
+                    errno));
+        } else {
+            LOGERR(("FileInterner::reapXattrs: pxattr::list: errno %d\n",
+                    errno));
+        }
 	return;
     }
     const map<string, string>& xtof = cfg->getXattrToField();
@@ -79,6 +85,7 @@ void reapXAttrs(const RclConfig* cfg, const string& path,
 	xfields[key] = value;
 	LOGDEB2(("reapXAttrs: [%s] -> [%s]\n", key.c_str(), value.c_str()));
     }
+#endif
 }
 
 void docFieldsFromXattrs(RclConfig *cfg, const map<string, string>& xfields, 
