@@ -1,4 +1,4 @@
-/* Copyright (C) 2005 J.F.Dockes 
+	/* Copyright (C) 2005 J.F.Dockes 
  *   This program is free software; you can redistribute it and/or modify
  *   it under the terms of the GNU General Public License as published by
  *   the Free Software Foundation; either version 2 of the License, or
@@ -32,7 +32,7 @@ using namespace std;
 #include "idfile.h"
 
 #include <sys/types.h>
-#include <sys/wait.h>
+#include "safesyswait.h"
 
 bool MimeHandlerExecMultiple::startCmd()
 {
@@ -47,9 +47,6 @@ bool MimeHandlerExecMultiple::startCmd()
     // Command name
     string cmd = params.front();
     
-    int filtermaxmbytes = 0;
-    m_config->getConfParam("filtermaxmbytes", &filtermaxmbytes);
-
     m_maxmemberkb = 50000;
     m_config->getConfParam("membermaxkbs", &m_maxmemberkb);
     ostringstream oss;
@@ -60,7 +57,9 @@ bool MimeHandlerExecMultiple::startCmd()
     m_cmd.putenv(m_forPreview ? "RECOLL_FILTER_FORPREVIEW=yes" :
 		"RECOLL_FILTER_FORPREVIEW=no");
 
-    m_cmd.setrlimit_as(filtermaxmbytes);
+    m_cmd.setrlimit_as(m_filtermaxmbytes);
+    m_adv.setmaxsecs(m_filtermaxseconds);
+    m_cmd.setAdvise(&m_adv);
 
     // Build parameter list: delete cmd name
     vector<string>myparams(params.begin() + 1, params.end());
@@ -90,6 +89,9 @@ bool MimeHandlerExecMultiple::readDataElement(string& name, string &data)
         LOGERR(("MHExecMultiple: getline error\n"));
         return false;
     }
+    
+    LOGDEB1(("MHEM:rde: line [%s]\n", ibuf.c_str()));
+
     // Empty line (end of message) ?
     if (!ibuf.compare("\n")) {
         LOGDEB(("MHExecMultiple: Got empty line\n"));
@@ -163,15 +165,28 @@ bool MimeHandlerExecMultiple::next_document()
 	return false;
     }
 
-    if (m_cmd.getChildPid() < 0 && !startCmd()) {
+    if (m_cmd.getChildPid() <= 0 && !startCmd()) {
         return false;
     }
 
     // Send request to child process. This maybe the first/only
     // request for a given file, or a continuation request. We send an
     // empty file name in the latter case.
+    // We also compute the file md5 before starting the extraction:
+    // under Windows, we may not be able to do it while the file
+    // is opened by the filter
     ostringstream obuf;
+    string file_md5;
     if (m_filefirst) {
+	if (!m_forPreview) {
+	    string md5, xmd5, reason;
+	    if (MD5File(m_fn, md5, &reason)) {
+		file_md5 = MD5HexPrint(md5, xmd5);
+	    } else {
+		LOGERR(("MimeHandlerExecM: cant compute md5 for [%s]: %s\n",
+			m_fn.c_str(), reason.c_str()));
+	    }
+	}
         obuf << "FileName: " << m_fn.length() << "\n" << m_fn;
         // m_filefirst is set to true by set_document_file()
         m_filefirst = false;
@@ -195,6 +210,8 @@ bool MimeHandlerExecMultiple::next_document()
         return false;
     }
 
+    m_adv.reset();
+
     // Read answer (multiple elements)
     LOGDEB1(("MHExecMultiple: reading answer\n"));
     bool eofnext_received = false;
@@ -206,7 +223,17 @@ bool MimeHandlerExecMultiple::next_document()
     string charset;
     for (int loop=0;;loop++) {
         string name, data;
-        if (!readDataElement(name, data)) {
+        try {
+            if (!readDataElement(name, data)) {
+                m_cmd.zapChild();
+                return false;
+            }
+        } catch (HandlerTimeout) {
+            LOGINFO(("MHExecMultiple: timeout\n"));
+            m_cmd.zapChild();
+            return false;
+        } catch (CancelExcept) {
+            LOGINFO(("MHExecMultiple: interrupt\n"));
             m_cmd.zapChild();
             return false;
         }
@@ -291,14 +318,8 @@ bool MimeHandlerExecMultiple::next_document()
         m_metaData[cstr_dj_keymt] = mtype.empty() ? "text/html" : mtype;
         m_metaData.erase(cstr_dj_keyipath);
 	if (!m_forPreview) {
-	    string md5, xmd5, reason;
-	    if (MD5File(m_fn, md5, &reason)) {
-		m_metaData[cstr_dj_keymd5] = MD5HexPrint(md5, xmd5);
-	    } else {
-		LOGERR(("MimeHandlerExecM: cant compute md5 for [%s]: %s\n",
-			m_fn.c_str(), reason.c_str()));
-	    }
-	}
+            m_metaData[cstr_dj_keymd5] = file_md5;
+        }
     }
 
     handle_cs(m_metaData[cstr_dj_keymt], charset);
