@@ -17,15 +17,13 @@
 #include "autoconfig.h"
 
 #include <stdio.h>
-#include <unistd.h>
-#include <sys/stat.h>
 #include <errno.h>
+#include "safefcntl.h"
+#include <sys/types.h>
+#include "safeunistd.h"
 
 #include <iostream>
 #include <string>
-#ifndef NO_NAMESPACES
-using namespace std;
-#endif /* NO_NAMESPACES */
 
 #include "cstr.h"
 #include "mh_text.h"
@@ -34,6 +32,9 @@ using namespace std;
 #include "md5ut.h"
 #include "rclconfig.h"
 #include "pxattr.h"
+#include "pathut.h"
+
+using namespace std;
 
 const int MB = 1024*1024;
 const int KB = 1024;
@@ -41,28 +42,35 @@ const int KB = 1024;
 // Process a plain text file
 bool MimeHandlerText::set_document_file(const string& mt, const string &fn)
 {
-    LOGDEB(("MimeHandlerText::set_document_file: [%s]\n", fn.c_str()));
+    LOGDEB(("MimeHandlerText::set_document_file: [%s] offs %s\n",
+            fn.c_str(), lltodecstr(m_offs).c_str()));
 
     RecollFilter::set_document_file(mt, fn);
+
     m_fn = fn;
+    // This should not be necessary, but it happens on msw that offset is large
+    // negative at this point, could not find the reason (still trying).
+    m_offs = 0;
 
     // file size for oversize check
-    struct stat st;
-    if (stat(m_fn.c_str(), &st) < 0) {
-        LOGERR(("MimeHandlerText::set_document_file: stat(%s) errno %d\n",
+    long long fsize = path_filesize(m_fn);
+    if (fsize < 0) {
+        LOGERR(("MimeHandlerText::set_document_file: stat %s errno %d\n",
                 m_fn.c_str(), errno));
         return false;
     }
 
+#ifndef _WIN32
     // Check for charset defined in extended attribute as per:
     // http://freedesktop.org/wiki/CommonExtendedAttributes
     pxattr::get(m_fn, "charset", &m_charsetfromxattr);
+#endif
 
     // Max file size parameter: texts over this size are not indexed
     int maxmbs = 20;
     m_config->getConfParam("textfilemaxmbs", &maxmbs);
 
-    if (maxmbs == -1 || st.st_size / MB <= maxmbs) {
+    if (maxmbs == -1 || fsize / MB <= maxmbs) {
         // Text file page size: if set, we split text files into
         // multiple documents
         int ps = 1000;
@@ -100,8 +108,9 @@ bool MimeHandlerText::set_document_string(const string& mt, const string& otext)
 
 bool MimeHandlerText::skip_to_document(const string& ipath)
 {
-    long long t;
-    if (sscanf(ipath.c_str(), "%lld", &t) != 1) {
+    char *endptr;
+    long long t = strtoll(ipath.c_str(), &endptr, 10);
+    if (endptr == ipath.c_str()) {
 	LOGERR(("MimeHandlerText::skip_to_document: bad ipath offs [%s]\n",
 		ipath.c_str()));
 	return false;
@@ -147,8 +156,7 @@ bool MimeHandlerText::next_document()
         // first chunk). This is a hack. The right thing to do would
         // be to use a different mtype for files over the page size,
         // and keep text/plain only for smaller files.
-        char buf[30];
-        sprintf(buf, "%lld", (long long)(m_offs - srclen));
+        string buf = lltodecstr(m_offs - srclen);
         if (m_offs - srclen != 0)
             m_metaData[cstr_dj_keyipath] = buf;
         readnext();
