@@ -28,14 +28,20 @@
  */
 class MimeHandlerUnknown : public RecollFilter {
  public:
-    MimeHandlerUnknown(RclConfig *cnf, const string& mt) 
-	: RecollFilter(cnf, mt) {}
-    virtual ~MimeHandlerUnknown() {}
-    virtual bool set_document_file(const string& fn) {
-	RecollFilter::set_document_file(fn);
+    MimeHandlerUnknown(RclConfig *cnf, const string& id) 
+	: RecollFilter(cnf, id) 
+    {
+    }
+    virtual ~MimeHandlerUnknown() 
+    {
+    }
+    virtual bool set_document_file(const string& mt, const string& fn) 
+    {
+	RecollFilter::set_document_file(mt, fn);
 	return m_havedoc = true;
     }
-    virtual bool set_document_string(const string&) {
+    virtual bool set_document_string(const string& mt, const string& s) {
+	RecollFilter::set_document_string(mt, s);
 	return m_havedoc = true;
     }
     virtual bool next_document() {
