@@ -32,6 +32,7 @@ using namespace std;
 #include "searchdata.h"
 #include "rclquery.h"
 #include "pathut.h"
+#include "rclutil.h"
 #include "wasatorcl.h"
 #include "debuglog.h"
 #include "pathut.h"
@@ -55,15 +56,15 @@ static RclConfig *rclconfig;
 typedef struct {
     PyObject_HEAD
     /* Type-specific fields go here. */
-    RefCntr<Rcl::SearchData> sd;
+    STD_SHARED_PTR<Rcl::SearchData> sd;
 } recoll_SearchDataObject;
 
 static void 
 SearchData_dealloc(recoll_SearchDataObject *self)
 {
     LOGDEB(("SearchData_dealloc. Releasing. Count before: %d\n",
-            self->sd.getcnt()));
-    self->sd.release();
+            self->sd.use_count()));
+    self->sd.reset();
     Py_TYPE(self)->tp_free((PyObject*)self);
 }
 
@@ -108,7 +109,7 @@ SearchData_init(recoll_SearchDataObject *self, PyObject *args, PyObject *kwargs)
     } else {
 	stemlang = "english";
     }
-    self->sd = RefCntr<Rcl::SearchData>(new Rcl::SearchData(tp, stemlang));
+    self->sd = STD_SHARED_PTR<Rcl::SearchData>(new Rcl::SearchData(tp, stemlang));
     return 0;
 }
 
@@ -180,7 +181,7 @@ SearchData_addclause(recoll_SearchDataObject* self, PyObject *args,
 		     PyObject *kwargs)
 {
     LOGDEB0(("SearchData_addclause\n"));
-    if (self->sd.isNull()) {
+    if (!self->sd) {
 	LOGERR(("SearchData_addclause: not init??\n"));
         PyErr_SetString(PyExc_AttributeError, "sd");
         return 0;
@@ -608,22 +609,13 @@ Doc_getattro(recoll_DocObject *self, PyObject *nameobj)
 static int
 Doc_setattr(recoll_DocObject *self, char *name, PyObject *value)
 {
-    LOGDEB0(("Doc_setattr: doc %p\n", self->doc));
     if (self->doc == 0 || the_docs.find(self->doc) == the_docs.end()) {
         PyErr_SetString(PyExc_AttributeError, "doc??");
 	return -1;
     }
-
-#if PY_MAJOR_VERSION < 3
-    if (PyString_Check(value)) {
-	value = PyUnicode_FromObject(value);
-	if (value == 0) 
-	    return -1;
-    } 
-#endif
-
-    if (!PyUnicode_Check(value)) {
-	PyErr_SetString(PyExc_AttributeError, "value not str/unicode??");
+    if (!rclconfig || !rclconfig->ok()) {
+	PyErr_SetString(PyExc_EnvironmentError,
+                        "Configuration not initialized");
 	return -1;
     }
     if (name == 0) {
@@ -631,6 +623,17 @@ Doc_setattr(recoll_DocObject *self, char *name, PyObject *value)
 	return -1;
     }
 
+    if (PyBytes_Check(value)) {
+	value = PyUnicode_FromEncodedObject(value, "UTF-8", "strict");
+	if (value == 0) 
+	    return -1;
+    }
+
+    if (!PyUnicode_Check(value)) {
+	PyErr_SetString(PyExc_AttributeError, "value not unicode??");
+	return -1;
+    }
+
     PyObject* putf8 = PyUnicode_AsUTF8String(value);
     if (putf8 == 0) {
 	LOGERR(("Doc_setmeta: encoding to utf8 failed\n"));
@@ -638,10 +641,11 @@ Doc_setattr(recoll_DocObject *self, char *name, PyObject *value)
 	return -1;
     }
     char* uvalue = PyBytes_AsString(putf8);
-    Py_DECREF(putf8);
     string key = rclconfig->fieldQCanon(string(name));
 
-    LOGDEB0(("Doc_setattr: [%s] (%s) -> [%s]\n", key.c_str(), name, uvalue));
+    LOGDEB0(("Doc_setattr: doc %p [%s] (%s) -> [%s]\n",
+             self->doc, key.c_str(), name, uvalue));
+
     // We set the value in the meta array in all cases. Good idea ? or do it
     // only for fields without a dedicated Doc:: entry?
     self->doc->meta[key] = uvalue;
@@ -695,6 +699,7 @@ Doc_setattr(recoll_DocObject *self, char *name, PyObject *value)
 	}
 	break;
     }
+    Py_DECREF(putf8);
     return 0;
 }
 
@@ -951,7 +956,7 @@ Query_execute(recoll_QueryObject* self, PyObject *args, PyObject *kwargs)
 	return 0;
     }
 
-    RefCntr<Rcl::SearchData> rq(sd);
+    STD_SHARED_PTR<Rcl::SearchData> rq(sd);
     self->query->setSortBy(*self->sortfield, self->ascending);
     self->query->setQuery(rq);
     int cnt = self->query->getResCnt();
@@ -1030,13 +1035,12 @@ Query_fetchone(PyObject *_self)
         PyErr_SetString(PyExc_EnvironmentError, "doc create failed");
 	return 0;
     }
-    if (self->next >= self->rowcount) {
-        PyErr_SetNone(PyExc_StopIteration);
-	return 0;
-    }
+
+    // We used to check against rowcount here, but this was wrong:
+    // xapian result count estimate are sometimes wrong, we must go on
+    // fetching until we fail
     if (!self->query->getDoc(self->next, *result->doc)) {
-        PyErr_SetString(PyExc_EnvironmentError, "query: cant fetch result");
-	self->next = -1;
+        PyErr_SetNone(PyExc_StopIteration);
 	return 0;
     }
     self->next++;
@@ -1076,8 +1080,7 @@ Query_fetchmany(recoll_QueryObject* self, PyObject *args, PyObject *kwargs)
     }
 
     PyObject *reslist = PyList_New(0);
-    int howmany = MIN(self->rowcount - self->next, size);
-    for (int i = 0; i < howmany; i++) {
+    for (int i = 0; i < size; i++) {
         recoll_DocObject *docobj = (recoll_DocObject *)
 	    PyObject_CallObject((PyObject *)&recoll_DocType, 0);
         if (!docobj) {
@@ -1085,9 +1088,8 @@ Query_fetchmany(recoll_QueryObject* self, PyObject *args, PyObject *kwargs)
             return 0;
         }
         if (!self->query->getDoc(self->next, *docobj->doc)) {
-            PyErr_SetString(PyExc_EnvironmentError, "can't fetch");
-            self->next = -1;
-            return 0;
+            PyErr_SetNone(PyExc_StopIteration);
+            break;
         }
         self->next++;
         movedocfields(docobj->doc);
@@ -1222,8 +1224,8 @@ Query_highlight(recoll_QueryObject* self, PyObject *args, PyObject *kwargs)
 	return 0;
     }
 
-    RefCntr<Rcl::SearchData> sd = self->query->getSD();
-    if (sd.isNull()) {
+    STD_SHARED_PTR<Rcl::SearchData> sd = self->query->getSD();
+    if (!sd) {
 	PyErr_SetString(PyExc_ValueError, "Query not initialized");
 	return 0;
     }
@@ -1273,8 +1275,8 @@ Query_makedocabstract(recoll_QueryObject* self, PyObject *args,PyObject *kwargs)
         PyErr_SetString(PyExc_AttributeError, "query");
         return 0;
     }
-    RefCntr<Rcl::SearchData> sd = self->query->getSD();
-    if (sd.isNull()) {
+    STD_SHARED_PTR<Rcl::SearchData> sd = self->query->getSD();
+    if (!sd) {
 	PyErr_SetString(PyExc_ValueError, "Query not initialized");
 	return 0;
     }
@@ -1329,8 +1331,8 @@ Query_getxquery(recoll_QueryObject* self, PyObject *, PyObject *)
         PyErr_SetString(PyExc_AttributeError, "query");
 	return 0;
     }
-    RefCntr<Rcl::SearchData> sd = self->query->getSD();
-    if (sd.isNull()) {
+    STD_SHARED_PTR<Rcl::SearchData> sd = self->query->getSD();
+    if (!sd) {
 	PyErr_SetString(PyExc_ValueError, "Query not initialized");
 	return 0;
     }
@@ -1357,8 +1359,8 @@ Query_getgroups(recoll_QueryObject* self, PyObject *, PyObject *)
         PyErr_SetString(PyExc_AttributeError, "query");
 	return 0;
     }
-    RefCntr<Rcl::SearchData> sd = self->query->getSD();
-    if (sd.isNull()) {
+    STD_SHARED_PTR<Rcl::SearchData> sd = self->query->getSD();
+    if (!sd) {
 	PyErr_SetString(PyExc_ValueError, "Query not initialized");
 	return 0;
     }
