@@ -16,6 +16,7 @@
  */
 #ifndef _ADVSEARCH_W_H_INCLUDED_
 #define _ADVSEARCH_W_H_INCLUDED_
+#include "autoconfig.h"
 
 #include <vector>
 
@@ -24,7 +25,7 @@
 
 #include "searchclause_w.h"
 #include "recoll.h"
-#include "refcntr.h"
+#include MEMORY_INCLUDE
 #include "searchdata.h"
 #include "advshist.h"
 
@@ -43,7 +44,6 @@ public:
 	setupUi(this);
 	init();
     }
-    ~AdvSearch(){}
 
 public slots:
     virtual void delFiltypPB_clicked();
@@ -56,18 +56,17 @@ public slots:
     virtual void restrictFtCB_toggled(bool);
     virtual void restrictCtCB_toggled(bool);
     virtual void runSearch();
-    virtual void fromSearch(RefCntr<Rcl::SearchData> sdata);
+    virtual void fromSearch(STD_SHARED_PTR<Rcl::SearchData> sdata);
     virtual void browsePB_clicked();
     virtual void saveFileTypes();
     virtual void delClause();
     virtual void addClause();
     virtual void addClause(int);
-    virtual bool close();
     virtual void slotHistoryNext();
     virtual void slotHistoryPrev();
 
 signals:
-    void startSearch(RefCntr<Rcl::SearchData>, bool);
+    void startSearch(STD_SHARED_PTR<Rcl::SearchData>, bool);
 
 private:
     virtual void init();
