@@ -14,7 +14,7 @@
  *   Free Software Foundation, Inc.,
  *   59 Temple Place - Suite 330, Boston, MA  02111-1307, USA.
  */
-#include <unistd.h>
+#include "autoconfig.h"
 
 #include <algorithm>
 #include <cstdio>
@@ -27,10 +27,8 @@
 #include "base64.h"
 #include "advshist.h"
 
-#include <QApplication>
 #include <QSettings>
 #include <QStringList>
-#include <QFileDialog>
 
 RclDynConf *g_dynconf;
 AdvSearchHist *g_advshistory;
@@ -151,8 +149,6 @@ void rwSettings(bool writing)
     SETTING_RW(prefs.reslistfontsize, "/Recoll/prefs/reslist/fontSize", Int, 
 	       10);
 
-    prefs.fontcolor = QApplication::palette().text().color().name();
-
     QString rlfDflt = QString::fromUtf8(prefs.dfltResListFormat);
     if (writing) {
 	if (prefs.reslistformat.compare(rlfDflt)) {
@@ -202,6 +198,10 @@ void rwSettings(bool writing)
     SETTING_RW(prefs.autoSuffsEnable, 
 	       "/Recoll/prefs/query/autoSuffsEnable", Bool, false);
 
+    SETTING_RW(prefs.synFileEnable, 
+	       "/Recoll/prefs/query/synFileEnable", Bool, false);
+    SETTING_RW(prefs.synFile, "/Recoll/prefs/query/synfile", String, "");
+    
     SETTING_RW(prefs.termMatchType, "/Recoll/prefs/query/termMatchType", 
 	       Int, 0);
     // This is not really the current program version, just a value to
@@ -414,32 +414,3 @@ string PrefsPack::stemlang()
     }
     return stemLang;
 }
-
-QString myGetFileName(bool isdir, QString caption, bool filenosave)
-{
-    LOGDEB1(("myFileDialog: isdir %d\n", isdir));
-    QFileDialog dialog(0, caption);
-
-    if (isdir) {
-	dialog.setFileMode(QFileDialog::Directory);
-	dialog.setOptions(QFileDialog::ShowDirsOnly);
-    } else {
-	dialog.setFileMode(QFileDialog::AnyFile);
-	if (filenosave)
-	    dialog.setAcceptMode(QFileDialog::AcceptOpen);
-	else
-	    dialog.setAcceptMode(QFileDialog::AcceptSave);
-    }
-    dialog.setViewMode(QFileDialog::List);
-    QFlags<QDir::Filter> flags = QDir::NoDotAndDotDot | QDir::Hidden; 
-    if (isdir)
-	flags |= QDir::Dirs;
-    else 
-	flags |= QDir::Dirs | QDir::Files;
-    dialog.setFilter(flags);
-
-    if (dialog.exec() == QDialog::Accepted) {
-        return dialog.selectedFiles().value(0);
-    }
-    return QString();
-}
