@@ -14,11 +14,8 @@
  *   Free Software Foundation, Inc.,
  *   59 Temple Place - Suite 330, Boston, MA  02111-1307, USA.
  */
-
-
 #include "autoconfig.h"
 
-#include <unistd.h>
 #include <cstdlib>
 
 #include <qapplication.h>
@@ -31,6 +28,7 @@
 #include <qcombobox.h>
 #include <QLocale>
 #include <QLibraryInfo>
+#include <QFileDialog>
 
 #include "rcldb.h"
 #include "rclconfig.h"
@@ -70,13 +68,18 @@ void forgetTempFile(string &fn)
     PTMutexLocker locker(thetempfileslock);
     for (vector<TempFile>::iterator it = o_tempfiles.begin();
 	 it != o_tempfiles.end(); it++) {
-	if ((*it).isNotNull() && !fn.compare((*it)->filename())) {
-	    it->release();
+	if ((*it) && !fn.compare((*it)->filename())) {
+	    it->reset();
 	}
     }
     fn.erase();
 }    
 
+void deleteAllTempFiles()
+{
+    PTMutexLocker locker(thetempfileslock);
+    o_tempfiles.clear();
+}
 
 Rcl::Db *rcldb;
 
@@ -154,9 +157,8 @@ static void recollCleanup()
     deleteZ(rcldb);
     deleteZ(theconfig);
 
-    PTMutexLocker locker(thetempfileslock);
-    o_tempfiles.clear();
-
+    deleteAllTempFiles();
+    
 #ifdef RCL_USE_ASPELL
     deleteZ(aspell);
 #endif
@@ -164,14 +166,6 @@ static void recollCleanup()
     LOGDEB2(("recollCleanup: done\n"));
 }
 
-static void sigcleanup(int)
-{
-    // We used to not call exit from here, because of the idxthread, but
-    // this is now gone, so...
-    recollNeedsExit = 1;
-    exit(1);
-}
-
 void applyStyleSheet(const QString& ssfname)
 {
     const char *cfname = (const char *)ssfname.toLocal8Bit();
@@ -305,7 +299,7 @@ int main(int argc, char **argv)
 
 
     string reason;
-    theconfig = recollinit(recollCleanup, sigcleanup, reason, &a_config);
+    theconfig = recollinit(recollCleanup, 0, reason, &a_config);
     if (!theconfig || !theconfig->ok()) {
 	QString msg = "Configuration problem: ";
 	msg += QString::fromUtf8(reason.c_str());
@@ -407,3 +401,32 @@ int main(int argc, char **argv)
     }
     return app.exec();
 }
+
+QString myGetFileName(bool isdir, QString caption, bool filenosave)
+{
+    LOGDEB1(("myFileDialog: isdir %d\n", isdir));
+    QFileDialog dialog(0, caption);
+
+    if (isdir) {
+	dialog.setFileMode(QFileDialog::Directory);
+	dialog.setOptions(QFileDialog::ShowDirsOnly);
+    } else {
+	dialog.setFileMode(QFileDialog::AnyFile);
+	if (filenosave)
+	    dialog.setAcceptMode(QFileDialog::AcceptOpen);
+	else
+	    dialog.setAcceptMode(QFileDialog::AcceptSave);
+    }
+    dialog.setViewMode(QFileDialog::List);
+    QFlags<QDir::Filter> flags = QDir::NoDotAndDotDot | QDir::Hidden; 
+    if (isdir)
+	flags |= QDir::Dirs;
+    else 
+	flags |= QDir::Dirs | QDir::Files;
+    dialog.setFilter(flags);
+
+    if (dialog.exec() == QDialog::Accepted) {
+        return dialog.selectedFiles().value(0);
+    }
+    return QString();
+}
