@@ -16,6 +16,7 @@
  */
 #ifndef _PREVIEW_W_H_INCLUDED_
 #define _PREVIEW_W_H_INCLUDED_
+#include "autoconfig.h"
 
 // Always use a qtextbrowser for now, there is no compelling reason to
 // switch to webkit here
@@ -25,6 +26,8 @@
 
 #include <stdio.h>
 
+#include MEMORY_INCLUDE
+
 #include <QComboBox>
 #include <qvariant.h>
 #include <qwidget.h>
@@ -39,7 +42,6 @@
 #include <qimage.h>
 
 #include "rcldb.h"
-#include "refcntr.h"
 #include "plaintorich.h"
 #include "rclmain_w.h"
 
@@ -54,7 +56,6 @@ class PreviewTextEdit : public PREVIEW_PARENTCLASS {
     Q_OBJECT;
 public:
     PreviewTextEdit(QWidget* parent, const char* name, Preview *pv);
-    virtual ~PreviewTextEdit();
     void moveToAnchor(const QString& name);
     enum DspType {PTE_DSPTXT, PTE_DSPFLDS, PTE_DSPIMG};
 
@@ -72,7 +73,7 @@ protected:
 
 private:
     Preview *m_preview;
-    PlainToRichQtPreview *m_plaintorich;
+    STD_SHARED_PTR<PlainToRichQtPreview> m_plaintorich;
     
     bool   m_dspflds;
     string m_url; // filename for this tab
@@ -130,14 +131,20 @@ class Preview : public QWidget {
     friend class PreviewTextEdit;
 
 public slots:
+    // Search stuff
     virtual void searchTextChanged(const QString& text);
     virtual void searchTextFromIndex(int);
     virtual void doSearch(const QString& str, bool next, bool reverse,
 			  bool wo = false);
     virtual void nextPressed();
     virtual void prevPressed();
+
+    // Tabs management
     virtual void currentChanged(int);
     virtual void closeCurrentTab();
+    virtual void emitShowNext();
+    virtual void emitShowPrev();
+
     virtual void emitSaveDocToFile();
     virtual void togglePlainPre();
 
