@@ -18,9 +18,7 @@
 
 /** Saving and restoring named queries */
 
-#include <fcntl.h>
-#include <sys/stat.h>
-#include <sys/types.h>
+#include "safesysstat.h"
 
 #include <QSettings>
 #include <QMessageBox>
@@ -43,7 +41,7 @@ static QString prevDir()
         settings.value("/Recoll/prefs/lastQuerySaveDir").toString();
     string defpath = path_cat(theconfig->getConfDir(), "saved_queries");
     if (prevdir.isEmpty()) {
-        if (access(defpath.c_str(), 0) != 0) {
+        if (!path_exists(defpath)) {
             mkdir(defpath.c_str(), 0700);
         }
         return QString::fromLocal8Bit(defpath.c_str());
@@ -59,7 +57,7 @@ void RclMain::saveLastQuery()
         xml = sSearch->asXML();
     } else {
         if (g_advshistory) {
-            RefCntr<Rcl::SearchData> sd;
+            STD_SHARED_PTR<Rcl::SearchData> sd;
             sd = g_advshistory->getnewest();
             if (sd) {
                 xml = sd->asXML();
@@ -118,7 +116,7 @@ void RclMain::loadSavedQuery()
     }
 
     // Try to parse as SearchData
-    RefCntr<SearchData> sd = xmlToSearchData(xml);
+    STD_SHARED_PTR<SearchData> sd = xmlToSearchData(xml);
     if (sd) {
         showAdvSearchDialog();
         asearchform->fromSearch(sd);
