@@ -16,6 +16,8 @@
  */
 #include "autoconfig.h"
 
+#include "safeunistd.h"
+
 #include <list>
 
 #include <QMessageBox>
@@ -66,9 +68,9 @@ void RclMain::viewUrl()
     // StartNativeViewer needs a db source to call getEnclosing() on.
     Rcl::Query *query = new Rcl::Query(rcldb);
     DocSequenceDb *src = 
-	new DocSequenceDb(RefCntr<Rcl::Query>(query), "", 
-			  RefCntr<Rcl::SearchData>(new Rcl::SearchData));
-    m_source = RefCntr<DocSequence>(src);
+	new DocSequenceDb(STD_SHARED_PTR<Rcl::Query>(query), "", 
+			  STD_SHARED_PTR<Rcl::SearchData>(new Rcl::SearchData));
+    m_source = STD_SHARED_PTR<DocSequence>(src);
 
 
     // Start a native viewer if the mimetype has one defined, else a
@@ -147,7 +149,7 @@ void RclMain::openWith(Rcl::Doc doc, string cmdspec)
     map<string, string> subs;
     subs["F"] = fn;
     subs["f"] = fn;
-    subs["U"] = url;
+    subs["U"] = url_encode(url);
     subs["u"] = url;
 
     execViewer(subs, false, execname, lcmd, cmdspec, doc);
@@ -271,7 +273,7 @@ void RclMain::startNativeViewer(Rcl::Doc doc, int pagenum, QString term)
 	// We want the path for the parent document. For example to
 	// open the chm file, not the internal page. Note that we just
 	// override the other file name in this case.
-	if (m_source.isNull() || !m_source->getEnclosing(doc, pdoc)) {
+	if (!m_source || !m_source->getEnclosing(doc, pdoc)) {
 	    QMessageBox::warning(0, "Recoll",
 				 tr("Cannot find parent document"));
 	    return;
@@ -291,12 +293,12 @@ void RclMain::startNativeViewer(Rcl::Doc doc, int pagenum, QString term)
     bool enterHistory = false;
     bool istempfile = false;
     
-    LOGDEB(("RclMain::startNV: groksipath %d wantsf %d wantsparentf %d\n", 
-	    groksipath, wantsfile, wantsparentfile));
+    LOGDEB(("RclMain::startNV: groksipath %d wantsf %d wantsparentf %d\n",
+            groksipath, wantsfile, wantsparentfile));
 
     // If the command wants a file but this is not a file url, or
     // there is an ipath that it won't understand, we need a temp file:
-    theconfig->setKeyDir(path_getfather(fn));
+    theconfig->setKeyDir(fn.empty() ? "" : path_getfather(fn));
     if (!doc.isFsFile() || 
         ((wantsfile || wantsparentfile) && fn.empty()) ||
 	(!groksipath && !doc.ipath.empty()) ) {
@@ -312,7 +314,7 @@ void RclMain::startNativeViewer(Rcl::Doc doc, int pagenum, QString term)
         istempfile = true;
 	rememberTempFile(temp);
 	fn = temp->filename();
-	url = string("file://") + fn;
+	url = path_pathtofileurl(fn);
     }
 
     // If using an actual file, check that it exists, and if it is
@@ -334,11 +336,11 @@ void RclMain::startNativeViewer(Rcl::Doc doc, int pagenum, QString term)
                 return;
             }
         }
-        if (!temp.isNull()) {
+        if (temp) {
             istempfile = true;
 	    rememberTempFile(temp);
             fn = temp->filename();
-            url = string("file://") + fn;
+            url = path_pathtofileurl(fn);
         }
     }
 
@@ -348,8 +350,7 @@ void RclMain::startNativeViewer(Rcl::Doc doc, int pagenum, QString term)
             "Recoll",
             tr("Opening a temporary copy. Edits will be lost if you don't save"
                "<br/>them to a permanent location."),
-            "Do not show this warning next time "
-            "(open GUI preferences to restore)");
+            tr("Do not show this warning next time (use GUI preferences to restore)."));
         confirm.setSettingsPath("Recoll/prefs");
         confirm.setOverrideSettingsKey("showTempFileWarning");
         confirm.exec();
@@ -360,7 +361,7 @@ void RclMain::startNativeViewer(Rcl::Doc doc, int pagenum, QString term)
     if (pagenum == -1) {
 	pagenum = 1;
 	string lterm;
-	if (m_source.isNotNull())
+	if (m_source)
 	    pagenum = m_source->getFirstMatchPage(doc, lterm);
 	if (pagenum == -1)
 	    pagenum = 1;
@@ -388,7 +389,7 @@ void RclMain::startNativeViewer(Rcl::Doc doc, int pagenum, QString term)
     subs["M"] = doc.mimetype;
     subs["p"] = cpagenum;
     subs["s"] = (const char*)term.toLocal8Bit();
-    subs["U"] = url;
+    subs["U"] = url_encode(url);
     subs["u"] = url;
     // Let %(xx) access all metadata.
     for (map<string,string>::const_iterator it = doc.meta.begin();
@@ -415,7 +416,9 @@ void RclMain::execViewer(const map<string, string>& subs, bool enterHistory,
     // Also substitute inside the unsplitted command line and display
     // in status bar
     pcSubst(cmd, ncmd, subs);
+#ifndef _WIN32
     ncmd += " &";
+#endif
     QStatusBar *stb = statusBar();
     if (stb) {
 	string fcharset = theconfig->getDefCharset(true);
@@ -433,7 +436,7 @@ void RclMain::execViewer(const map<string, string>& subs, bool enterHistory,
     zg_send_event(ZGSEND_OPEN, doc);
 
     // We keep pushing back and never deleting. This can't be good...
-    ExecCmd *ecmd = new ExecCmd;
+    ExecCmd *ecmd = new ExecCmd(ExecCmd::EXF_SHOWWINDOW);
     m_viewers.push_back(ecmd);
     ecmd->startExec(execpath, lcmd, false, false);
 }
@@ -445,16 +448,35 @@ void RclMain::startManual()
 
 void RclMain::startManual(const string& index)
 {
-    Rcl::Doc doc;
-    doc.url = "file://";
-    doc.url = path_cat(doc.url, theconfig->getDatadir());
-    doc.url = path_cat(doc.url, "doc");
-    doc.url = path_cat(doc.url, "usermanual.html");
+    string docdir = path_cat(theconfig->getDatadir(), "doc");
+
+    // The single page user manual is nicer if we have an index. Else
+    // the webhelp one is nicer if it is present
+    string usermanual = path_cat(docdir, "usermanual.html");
+    string webhelp = path_cat(docdir, "webhelp");
+    webhelp = path_cat(webhelp, "index.html");
+    bool has_wh = path_exists(webhelp);
+    
     LOGDEB(("RclMain::startManual: help index is %s\n", 
 	    index.empty()?"(null)":index.c_str()));
-    if (!index.empty()) {
-	doc.url += "#";
-	doc.url += index;
+    bool indexempty = index.empty();
+
+#ifdef _WIN32
+    // On Windows I could not find any way to pass the fragment through
+    // rclstartw (tried to set text/html as exception with rclstartw %u).
+    // So always start the webhelp
+    indexempty = true;
+#endif
+    
+    if (!indexempty) {
+	usermanual += "#";
+	usermanual += index;
+    }
+    Rcl::Doc doc;
+    if (has_wh && indexempty) {
+        doc.url = path_pathtofileurl(webhelp);
+    } else {
+        doc.url = path_pathtofileurl(usermanual);
     }
     doc.mimetype = "text/html";
     startNativeViewer(doc);
