@@ -21,6 +21,7 @@
 
 #include "rclconfig.h"
 #include "rcldb.h"
+#include "rclutil.h"
 #include "ptmutex.h"
 
 #include <QString>
@@ -38,6 +39,7 @@ extern RclConfig *theconfig;
 
 extern void rememberTempFile(TempFile);
 extern void forgetTempFile(string &fn);
+extern void deleteAllTempFiles();
 
 extern Rcl::Db *rcldb;
 extern int recollNeedsExit;
@@ -54,4 +56,10 @@ inline std::string qs2utf8s(const QString& qs)
 {
     return std::string((const char *)qs.toUtf8());
 }
+
+/** Specialized version of the qt file dialog. Can't use getOpenFile()
+   etc. cause they hide dot files... */
+extern QString myGetFileName(bool isdir, QString caption = QString(),
+			     bool filenosave = false);
+
 #endif /* _RECOLL_H_INCLUDED_ */
