@@ -16,15 +16,16 @@
  */
 #ifndef _RESTABLE_H_INCLUDED_
 #define _RESTABLE_H_INCLUDED_
+#include "autoconfig.h"
 
 #include <Qt>
 
 #include <string>
 #include <map>
 #include <vector>
+#include MEMORY_INCLUDE
 
 #include "ui_restable.h"
-#include "refcntr.h"
 #include "docseq.h"
 #include "plaintorich.h"
 
@@ -50,8 +51,8 @@ public:
     virtual void sort(int column, Qt::SortOrder order = Qt::AscendingOrder);
     // Specific methods
     virtual void readDocSource();
-    virtual void setDocSource(RefCntr<DocSequence> nsource);
-    virtual RefCntr<DocSequence> getDocSource() {return m_source;}
+    virtual void setDocSource(STD_SHARED_PTR<DocSequence> nsource);
+    virtual STD_SHARED_PTR<DocSequence> getDocSource() {return m_source;}
     virtual void deleteColumn(int);
     virtual const std::vector<std::string>& getFields() {return m_fields;}
     virtual const std::map<std::string, QString>& getAllFields() 
@@ -72,7 +73,7 @@ signals:
     void sortDataChanged(DocSeqSortSpec);
 
 private:
-    mutable RefCntr<DocSequence> m_source;
+    mutable STD_SHARED_PTR<DocSequence> m_source;
     std::vector<std::string> m_fields;
     std::vector<FieldGetter*> m_getters;
     static std::map<std::string, QString> o_displayableFields;
@@ -126,7 +127,7 @@ public:
 public slots:
     virtual void onTableView_currentChanged(const QModelIndex&);
     virtual void on_tableView_entered(const QModelIndex& index);
-    virtual void setDocSource(RefCntr<DocSequence> nsource);
+    virtual void setDocSource(STD_SHARED_PTR<DocSequence> nsource);
     virtual void saveColState();
     virtual void resetSource();
     virtual void readDocSource(bool resetPos = true);
