@@ -16,7 +16,6 @@
  */
 #include "autoconfig.h"
 
-#include <unistd.h>
 #include <stdio.h>
 
 #include <string>
@@ -65,7 +64,7 @@ static PlainToRichQtSnippets g_hiliter;
 
 void SnippetsW::init()
 {
-    if (m_source.isNull())
+    if (!m_source)
 	return;
 
     QPushButton *searchButton = new QPushButton(tr("Search"));
