@@ -14,8 +14,11 @@
  *   Free Software Foundation, Inc.,
  *   59 Temple Place - Suite 330, Boston, MA  02111-1307, USA.
  */
+#include "autoconfig.h"
+
 #include <sstream>
 #include <set>
+#include MEMORY_INCLUDE
 
 #include <qapplication.h>
 #include <qinputdialog.h>
@@ -34,7 +37,6 @@
 #include "guiutils.h"
 #include "searchdata.h"
 #include "ssearch_w.h"
-#include "refcntr.h"
 #include "textsplit.h"
 #include "wasatorcl.h"
 #include "rclhelp.h"
@@ -151,7 +153,7 @@ void SSearch::searchTypeChanged(int typ)
 			       "RCL.SEARCH.LANG");
     else 
 	HelpClient::installMap((const char *)this->objectName().toUtf8(), 
-			       "RCL.SEARCH.SIMPLE");
+			       "RCL.SEARCH.GUI.SIMPLE");
 
     // Also fix tooltips
     switch (typ) {
@@ -309,7 +311,7 @@ bool SSearch::startSimpleSearch(const string& u8, int maxexp)
     m_xml = xml.str();
     LOGDEB(("SSearch::startSimpleSearch:xml:[%s]\n", m_xml.c_str()));
 
-    RefCntr<Rcl::SearchData> rsdata(sdata);
+    STD_SHARED_PTR<Rcl::SearchData> rsdata(sdata);
     emit startSearch(rsdata, true);
     return true;
 }
