@@ -16,6 +16,7 @@
  */
 #ifndef _SSEARCH_W_H_INCLUDED_
 #define _SSEARCH_W_H_INCLUDED_
+#include "autoconfig.h"
 
 #include <string>
 
@@ -26,7 +27,7 @@ class QTimer;
 
 #include "recoll.h"
 #include "searchdata.h"
-#include "refcntr.h"
+#include MEMORY_INCLUDE
 
 #include "ui_ssearchb.h"
 
@@ -72,7 +73,7 @@ public slots:
     virtual void takeFocus();
 
 signals:
-    void startSearch(RefCntr<Rcl::SearchData>, bool);
+    void startSearch(STD_SHARED_PTR<Rcl::SearchData>, bool);
     void clearSearch();
  private:
     bool m_escape;
