@@ -47,7 +47,7 @@ static bool filter(const DocSeqFiltSpec& fs, const Rcl::Doc *x)
     return false;
 } 
 
-DocSeqFiltered::DocSeqFiltered(RclConfig *conf, RefCntr<DocSequence> iseq, 
+DocSeqFiltered::DocSeqFiltered(RclConfig *conf, STD_SHARED_PTR<DocSequence> iseq, 
 			       DocSeqFiltSpec &filtspec)
     :  DocSeqModifier(iseq), m_config(conf)
 {
@@ -106,7 +106,6 @@ bool DocSeqFiltered::getDoc(int idx, Rcl::Doc &doc, string *)
 
 	// Loop until we get enough docs
 	Rcl::Doc tdoc;
-	int i = 0;
 	while (idx >= (int)m_dbindices.size()) {
 	    if (!m_seq->getDoc(backend_idx, tdoc)) 
 		return false;
