@@ -16,11 +16,12 @@
  */
 #ifndef _SORTSEQ_H_INCLUDED_
 #define _SORTSEQ_H_INCLUDED_
+#include "autoconfig.h"
 
 #include <vector>
 #include <string>
+#include MEMORY_INCLUDE
 
-#include "refcntr.h"
 #include "docseq.h"
 
 /** 
@@ -29,7 +30,7 @@
  */
 class DocSeqSorted : public DocSeqModifier {
  public:
-    DocSeqSorted(RefCntr<DocSequence> iseq, DocSeqSortSpec &sortspec)
+    DocSeqSorted(STD_SHARED_PTR<DocSequence> iseq, DocSeqSortSpec &sortspec)
 	:  DocSeqModifier(iseq)
     {
 	setSortSpec(sortspec);
@@ -38,7 +39,7 @@ class DocSeqSorted : public DocSeqModifier {
     virtual bool canSort() {return true;}
     virtual bool setSortSpec(const DocSeqSortSpec &sortspec);
     virtual bool getDoc(int num, Rcl::Doc &doc, string *sh = 0);
-    virtual int getResCnt() {return m_docsp.size();}
+    virtual int getResCnt() {return int(m_docsp.size());}
  private:
     DocSeqSortSpec          m_spec;
     std::vector<Rcl::Doc>   m_docs;
