@@ -19,9 +19,6 @@
 #include <math.h>
 
 #include <map>
-#include "unordered_defs.h"
-
-using namespace std;
 
 #include "debuglog.h"
 #include "rcldb.h"
@@ -32,6 +29,9 @@ using namespace std;
 #include "searchdata.h"
 #include "utf8iter.h"
 #include "hldata.h"
+#include "chrono.h"
+
+using namespace std;
 
 namespace Rcl {
 // This is used as a marker inside the abstract frag lists, but
@@ -83,7 +83,7 @@ bool Query::Native::getMatchTerms(unsigned long xdocid, vector<string>& terms)
 {
     if (!xenquire) {
 	LOGERR(("Query::getMatchTerms: no query opened\n"));
-	return -1;
+	return false;
     }
 
     terms.clear();
@@ -158,7 +158,7 @@ double Query::Native::qualityTerms(Xapian::docid docid,
     if (doclen == 0) 
 	doclen = 1;
     HighlightData hld;
-    if (!m_q->m_sd.isNull()) {
+    if (m_q->m_sd) {
 	m_q->m_sd->getTerms(hld);
     }
 
@@ -174,7 +174,6 @@ double Query::Native::qualityTerms(Xapian::docid docid,
     map<string, vector<string> > byRoot;
     for (vector<string>::const_iterator qit = terms.begin(); 
 	 qit != terms.end(); qit++) {
-	bool found = false;
 	map<string, string>::const_iterator eit = hld.terms.find(*qit);
 	if (eit != hld.terms.end()) {
 	    byRoot[eit->second].push_back(*qit);
@@ -281,7 +280,6 @@ int Query::Native::getFirstMatchPage(Xapian::docid docid, string& term)
 
     // We try to use a page which matches the "best" term. Get a sorted list
     multimap<double, vector<string> > byQ;
-    double totalweight = qualityTerms(docid, terms, byQ);
 
     for (multimap<double, vector<string> >::reverse_iterator mit = byQ.rbegin(); 
 	 mit != byQ.rend(); mit++) {
@@ -387,7 +385,7 @@ int Query::Native::makeAbstract(Xapian::docid docid,
     for (multimap<double, vector<string> >::reverse_iterator mit = byQ.rbegin(); 
 	 mit != byQ.rend(); mit++) {
 	unsigned int maxgrpoccs;
-	float q;
+	double q;
 	if (byQ.size() == 1) {
 	    maxgrpoccs = maxtotaloccs;
 	    q = 1.0;
