@@ -18,7 +18,7 @@
 
 #include <stdio.h>
 #include <cstring>
-#include <unistd.h>
+#include "safeunistd.h"
 #include <math.h>
 #include <time.h>
 
@@ -26,6 +26,7 @@
 #include <vector>
 #include <algorithm>
 #include <sstream>
+#include <iostream>
 
 using namespace std;
 
@@ -41,7 +42,9 @@ using namespace std;
 #include "unacpp.h"
 #include "conftree.h"
 #include "pathut.h"
+#include "rclutil.h"
 #include "smallut.h"
+#include "chrono.h"
 #include "utf8iter.h"
 #include "searchdata.h"
 #include "rclquery.h"
@@ -72,8 +75,8 @@ static const string xapday_prefix = "D";
 static const string xapmonth_prefix = "M";
 static const string xapyear_prefix = "Y";
 const string pathelt_prefix = "XP";
-const string udi_prefix("Q");
-const string parent_prefix("F");
+static const string udi_prefix("Q");
+static const string parent_prefix("F");
 
 // Special terms to mark begin/end of field (for anchored searches), and
 // page breaks
@@ -124,6 +127,21 @@ static inline string make_parentterm(const string& udi)
     return pterm;
 }
 
+static void utf8truncate(string& s, int maxlen)
+{
+    if (s.size() <= string::size_type(maxlen)) {
+        return;
+    }
+    Utf8Iter iter(s);
+    string::size_type pos = 0;
+    while (iter++ != string::npos)
+        if (iter.getBpos() < string::size_type(maxlen)) {
+            pos = iter.getBpos();
+        }
+
+    s.erase(pos);
+}
+
 Db::Native::Native(Db *db) 
     : m_rcldb(db), m_isopen(false), m_iswritable(false),
       m_noversionwrite(false)
@@ -434,7 +452,7 @@ bool Db::Native::dbDataToRclDoc(Xapian::docid docid, std::string &data,
     string dbdir = m_rcldb->m_basedir;
     doc.idxi = 0;
     if (!m_rcldb->m_extraDbs.empty()) {
-	unsigned int idxi = whatDbIdx(docid);
+	int idxi = int(whatDbIdx(docid));
 
 	// idxi is in [0, extraDbs.size()]. 0 is for the main index,
 	// idxi-1 indexes into the additional dbs array.
@@ -550,14 +568,13 @@ bool Db::Native::getPagePositions(Xapian::docid docid, vector<int>& vpos)
     return true;
 }
 
-int Db::Native::getPageNumberForPosition(const vector<int>& pbreaks, 
-					 unsigned int pos)
+int Db::Native::getPageNumberForPosition(const vector<int>& pbreaks, int pos)
 {
-    if (pos < baseTextPosition) // Not in text body
+    if (pos < int(baseTextPosition)) // Not in text body
 	return -1;
     vector<int>::const_iterator it = 
 	upper_bound(pbreaks.begin(), pbreaks.end(), pos);
-    return it - pbreaks.begin() + 1;
+    return int(it - pbreaks.begin() + 1);
 }
 
 // Note: we're passed a Xapian::Document* because Xapian
@@ -571,7 +588,7 @@ bool Db::Native::addOrUpdateWrite(const string& udi, const string& uniterm,
     Chrono chron;
     PTMutexLocker lock(m_mutex);
 #endif
-    RefCntr<Xapian::Document> doc_cleaner(newdocument_ptr);
+    STD_SHARED_PTR<Xapian::Document> doc_cleaner(newdocument_ptr);
 
     // Check file system full every mbyte of indexed text. It's a bit wasteful
     // to do this after having prepared the document, but it needs to be in
@@ -763,6 +780,7 @@ bool Db::open(OpenMode mode, OpenError *error)
     }
     if (!m_config->getStopfile().empty())
 	m_stops.setFile(m_config->getStopfile());
+
     string dir = m_config->getDbDir();
     string ermsg;
     try {
@@ -1236,6 +1254,11 @@ void Db::setAbstractParams(int idxtrunc, int syntlen, int syntctxlen)
 	m_synthAbsWordCtxLen = syntctxlen;
 }
 
+bool Db::setSynGroupsFile(const string& fn)
+{
+    return m_syngroups.setfile(fn);
+}
+    
 static const string cstr_nc("\n\r\x0c\\");
 #define RECORD_APPEND(R, NM, VAL) {R += NM + "=" + VAL + "\n";}
 
@@ -1303,7 +1326,7 @@ bool Db::addOrUpdate(const string &udi, const string &parent_udi, Doc &doc)
 
 	// Split and index the path from the url for path-based filtering
 	{
-	    string path = url_gpath(doc.url);
+	    string path = url_gpathS(doc.url);
 	    vector<string> vpath;
 	    stringToTokens(path, vpath, "/");
 	    // If vpath is not /, the last elt is the file/dir name, not a
@@ -1322,6 +1345,7 @@ bool Db::addOrUpdate(const string &udi, const string &parent_udi, Doc &doc)
 		newdocument.add_posting(wrap_prefix(pathelt_prefix) + *it, 
 					splitter.basepos + splitter.curpos++);
 	    }
+            splitter.basepos += splitter.curpos + 100;
 	}
 
 	// Index textual metadata.  These are all indexed as text with
@@ -1417,10 +1441,11 @@ bool Db::addOrUpdate(const string &udi, const string &parent_udi, Doc &doc)
 	time_t mtime = atoll(doc.dmtime.empty() ? doc.fmtime.c_str() : 
 			     doc.dmtime.c_str());
         struct tm tmb;
-	localtime_r(&mtime, &tmb);
-	char buf[9];
-	snprintf(buf, 9, "%04d%02d%02d",
-		 tmb.tm_year+1900, tmb.tm_mon + 1, tmb.tm_mday);
+        localtime_r(&mtime, &tmb);
+        char buf[9];
+        snprintf(buf, 9, "%04d%02d%02d",
+                 tmb.tm_year+1900, tmb.tm_mon + 1, tmb.tm_mday);
+            
 	// Date (YYYYMMDD)
 	newdocument.add_boolean_term(wrap_prefix(xapday_prefix) + string(buf)); 
 	// Month (YYYYMM)
@@ -1497,13 +1522,11 @@ bool Db::addOrUpdate(const string &udi, const string &parent_udi, Doc &doc)
 	// document. This is then not indexed, but part of the doc data so
 	// that we can return it to a query without having to decode the
 	// original file.
-	bool syntabs = false;
 	// Note that the map accesses by operator[] create empty entries if they
 	// don't exist yet.
         string& absref = doc.meta[Doc::keyabs];
 	trimstring(absref, " \t\r\n");
 	if (absref.empty()) {
-	    syntabs = true;
 	    if (!doc.text.empty())
 		absref = cstr_syntAbs + 
 		    neutchars(truncate_to_word(doc.text, m_idxAbsTruncLen), 
@@ -1687,8 +1710,8 @@ void Db::waitUpdIdle()
 	    LOGERR(("Db::waitUpdIdle: flush() failed: %s\n", ermsg.c_str()));
 	}
 	m_ndb->m_totalworkns += chron.nanos();
-	LOGINFO(("Db::waitUpdIdle: total xapian work %lld mS\n",
-		 m_ndb->m_totalworkns/1000000));
+	LOGINFO(("Db::waitUpdIdle: total xapian work %s mS\n",
+		 lltodecstr(m_ndb->m_totalworkns/1000000).c_str()));
     }
 }
 #endif
