@@ -21,14 +21,15 @@
 
 #include <string>
 #include <vector>
+#include MEMORY_INCLUDE
 
 #include "cstr.h"
-#include "refcntr.h"
 #include "rcldoc.h"
 #include "stoplist.h"
 #include "rclconfig.h"
 #include "utf8iter.h"
 #include "textsplit.h"
+#include "syngroups.h"
 
 using std::string;
 using std::vector;
@@ -340,8 +341,9 @@ class Db {
      * Stem expansion is performed if lang is not empty 
      * 
      * @param typ_sens defines the kind of expansion: none, wildcard, 
-     *    regexp or stemming. "none" will still expand case and
-     *    diacritics depending on the casesens and diacsens flags.
+     *    regexp or stemming. "none" may still expand case,
+     *    diacritics and synonyms, depending on the casesens, diacsens and 
+     *    synexp flags.
      * @param lang sets the stemming language(s). Can be a space-separated list
      * @param term is the term to expand
      * @param result is the main output
@@ -353,14 +355,14 @@ class Db {
      *        in the TermMatchResult header
      */
     enum MatchType {ET_NONE=0, ET_WILD=1, ET_REGEXP=2, ET_STEM=3, 
-		    ET_DIACSENS=8, ET_CASESENS=16};
+		    ET_DIACSENS=8, ET_CASESENS=16, ET_SYNEXP=32};
     int matchTypeTp(int tp) 
     {
 	return tp & 7;
     }
     bool termMatch(int typ_sens, const string &lang, const string &term, 
-		   TermMatchResult& result, int max = -1, 
-		   const string& field = cstr_null);
+		   TermMatchResult& result, int max = -1,
+		   const string& field = "", vector<string> *multiwords = 0);
     bool dbStats(DbStats& stats);
     /** Return min and max years for doc mod times in db */
     bool maxYearSpan(int *minyear, int *maxyear);
@@ -454,6 +456,9 @@ class Db {
     }
     bool doFlush();
 
+    // Use empty fn for no synonyms
+    bool setSynGroupsFile(const std::string& fn);
+    
     /* This has to be public for access by embedded Query::Native */
     Native *m_ndb; 
 private:
@@ -475,11 +480,21 @@ private:
     // First fs occup check ?
     int         m_occFirstCheck;
 
+    // Synonym groups. There is no strict reason that this has to be
+    // an Rcl::Db member, as it is only used when building each It
+    // could be a SearchData member, or even a parameter to
+    // Query::setQuery(). Otoh, building the syngroups structure from
+    // a file may be expensive and it's unlikely to change with every
+    // query, so it makes sense to cache it, and Rcl::Db is not a bad
+    // place for this.
+    SynGroups m_syngroups;
+
     /***************
      * Parameters cached out of the configuration files. Logically const 
      * after init */
     // Stop terms: those don't get indexed.
     StopList m_stops;
+
     // Truncation length for stored meta fields
     int         m_idxMetaStoredLen;
     // This is how long an abstract we keep or build from beginning of
@@ -533,8 +548,6 @@ private:
 string version_string();
 
 extern const string pathelt_prefix;
-extern const string udi_prefix;
-extern const string parent_prefix;
 extern const string mimetype_prefix;
 extern const string unsplitFilenameFieldName;
 extern string start_of_field_term;
