@@ -14,6 +14,7 @@
  *   Free Software Foundation, Inc.,
  *   59 Temple Place - Suite 330, Boston, MA  02111-1307, USA.
  */
+#include "autoconfig.h"
 
 #include <stdlib.h>
 #include <string.h>
@@ -21,7 +22,6 @@
 
 #include <vector>
 #include <sstream>
-using namespace std;
 
 #include "xapian.h"
 
@@ -34,9 +34,12 @@ using namespace std;
 #include "rclquery_p.h"
 #include "conftree.h"
 #include "smallut.h"
+#include "chrono.h"
 #include "searchdata.h"
 #include "unacpp.h"
 
+using namespace std;
+
 namespace Rcl {
 // This is used as a marker inside the abstract frag lists, but
 // normally doesn't remain in final output (which is built with a
@@ -171,7 +174,7 @@ void Query::setSortBy(const string& fld, bool ascending) {
 #define ISNULL(X) !(X)
 
 // Prepare query out of user search data
-bool Query::setQuery(RefCntr<SearchData> sdata)
+bool Query::setQuery(STD_SHARED_PTR<SearchData> sdata)
 {
     LOGDEB(("Query::setQuery:\n"));
 
