@@ -34,7 +34,6 @@ public:
     /** The query I belong to */
     Query                *m_q;
 
-
     /** query descriptor: terms and subqueries joined by operators
      * (or/and etc...)
      */
@@ -47,14 +46,26 @@ public:
 
     Native(Query *q)
 	: m_q(q), xenquire(0)
-    { }
-    ~Native() {
+    { 
+    }
+    ~Native() 
+    {
 	clear();
     }
-    void clear() {
+    void clear() 
+    {
 	delete xenquire; xenquire = 0;
 	termfreqs.clear();
     }
+    /** Return a list of terms which matched for a specific result document */
+    bool getMatchTerms(unsigned long xdocid, std::vector<std::string>& terms);
+    int makeAbstract(Xapian::docid id, vector<Snippet>&,
+		     int maxoccs = -1, int ctxwords = -1);
+    int getFirstMatchPage(Xapian::docid docid, std::string& term);
+    void setDbWideQTermsFreqs();
+    double qualityTerms(Xapian::docid docid, 
+			const std::vector<std::string>& terms,
+			std::multimap<double, std::vector<std::string> >& byQ);
 };
 
 }
