@@ -91,11 +91,11 @@ bool SearchData::maybeAddAutoPhrase(Rcl::Db& db, double freqThreshold)
 
     string field;
     vector<string> words;
-    // Walk the clause list. If we find any non simple clause or different
-    // field names, bail out.
+    // Walk the clause list. If this is not an AND list, we find any
+    // non simple clause or different field names, bail out.
     for (qlist_it_t it = m_query.begin(); it != m_query.end(); it++) {
         SClType tp = (*it)->m_tp;
-        if (tp != SCLT_AND && tp != SCLT_OR) {
+        if (tp != SCLT_AND) {
             LOGDEB2(("SearchData::maybeAddAutoPhrase: wrong tp %d\n", tp));
             return false;
         }
@@ -162,7 +162,7 @@ bool SearchData::maybeAddAutoPhrase(Rcl::Db& db, double freqThreshold)
     // an actual user-entered phrase
     slack += 1 + nwords / 3;
     
-    m_autophrase = RefCntr<SearchDataClauseDist>(
+    m_autophrase = STD_SHARED_PTR<SearchDataClauseDist>(
         new SearchDataClauseDist(SCLT_PHRASE, swords, slack, field));
     return true;
 }
@@ -181,7 +181,8 @@ bool SearchData::addClause(SearchDataClause* cl)
     return true;
 }
 
-// Am I a file name only search ? This is to turn off term highlighting
+// Am I a file name only search ? This is to turn off term highlighting.
+// There can't be a subclause in a filename search: no possible need to recurse
 bool SearchData::fileNameOnly() 
 {
     for (qlist_it_t it = m_query.begin(); it != m_query.end(); it++)
@@ -190,6 +191,7 @@ bool SearchData::fileNameOnly()
     return true;
 }
 
+// The query language creates a lot of subqueries. See if we can merge them.
 void SearchData::simplify()
 {
     for (unsigned int i = 0; i < m_query.size(); i++) {
@@ -261,7 +263,7 @@ void SearchData::simplify()
              j < i + clsubp->getSub()->m_query.size(); j++) {
             m_query[j]->setParent(this);
         }
-        i += clsubp->getSub()->m_query.size() - 1;
+        i += int(clsubp->getSub()->m_query.size()) - 1;
 
         // We don't want the clauses to be deleted when the parent is, as we
         // know own them.
@@ -270,24 +272,15 @@ void SearchData::simplify()
     }
 }
 
-bool SearchData::singleSimple()
-{
-    if (m_query.size() != 1 || !m_filetypes.empty() || !m_nfiletypes.empty() ||
-        m_haveDates || m_maxSize != size_t(-1) || m_minSize != size_t(-1) ||
-        m_haveWildCards)
-        return false;
-    SearchDataClause *clp = *m_query.begin();
-    if (clp->getTp() != SCLT_AND && clp->getTp() != SCLT_OR) {
-        return false;
-    }
-    return true;
-}
-
-// Extract all term data
+// Extract terms and groups for highlighting
 void SearchData::getTerms(HighlightData &hld) const
 {
-    for (qlist_cit_t it = m_query.begin(); it != m_query.end(); it++)
-        (*it)->getTerms(hld);
+    for (qlist_cit_t it = m_query.begin(); it != m_query.end(); it++) {
+	if (!((*it)->getmodifiers() & SearchDataClause::SDCM_NOTERMS) &&
+	    !(*it)->getexclude()) {
+	    (*it)->getTerms(hld);
+	}
+    }
     return;
 }
 
@@ -374,7 +367,7 @@ void SearchDataClauseSub::dump(ostream& o) const
 {
     o << "ClauseSub {\n";
     dumptabs += '\t';
-    m_sub.getconstptr()->dump(o);
+    m_sub->dump(o);
     dumptabs.erase(dumptabs.size()- 1);
     o << dumptabs << "}";
 }
