@@ -29,7 +29,7 @@
 #include <ostream>
 
 #include "rcldb.h"
-#include "refcntr.h"
+#include MEMORY_INCLUDE
 #include "smallut.h"
 #include "cstr.h"
 #include "hldata.h"
@@ -96,9 +96,6 @@ public:
     /** Is there anything but a file name search in here ? */
     bool fileNameOnly();
 
-    /** Are we a simple query with one clause? */
-    bool singleSimple();
-
     /** Do we have wildcards anywhere apart from filename searches ? */
     bool haveWildCards() {return m_haveWildCards;}
 
@@ -152,9 +149,11 @@ public:
     {
 	m_tp = tp;
     }
+
     SClType getTp() {
         return m_tp;
     }
+    
     void setMaxExpand(int max)
     {
 	m_softmaxexpand = max;
@@ -179,7 +178,7 @@ private:
     std::vector<std::string>            m_nfiletypes;
     // Autophrase if set. Can't be part of the normal chain because
     // it uses OP_AND_MAYBE
-    RefCntr<SearchDataClauseDist>   m_autophrase;
+    STD_SHARED_PTR<SearchDataClauseDist>   m_autophrase;
 
     // Special stuff produced by input which looks like a clause but means
     // something else (date and size specs)
@@ -229,8 +228,11 @@ private:
 
 class SearchDataClause {
 public:
-    enum Modifier {SDCM_NONE=0, SDCM_NOSTEMMING=1, SDCM_ANCHORSTART=2,
-		   SDCM_ANCHOREND=4, SDCM_CASESENS=8, SDCM_DIACSENS=16};
+    enum Modifier {SDCM_NONE=0, SDCM_NOSTEMMING=0x1, SDCM_ANCHORSTART=0x2,
+		   SDCM_ANCHOREND=0x4, SDCM_CASESENS=0x8, SDCM_DIACSENS=0x10,
+		   SDCM_NOTERMS=0x20, // Don't include terms for highlighting
+		   SDCM_NOSYNS = 0x40, // Don't perform synonym expansion
+    };
     enum Relation {REL_CONTAINS, REL_EQUALS, REL_LT, REL_LTE, REL_GT, REL_GTE};
 
     SearchDataClause(SClType tp) 
@@ -272,7 +274,7 @@ public:
     {
 	return m_parentSearch ? m_parentSearch->getMaxExp() : 10000;
     }
-    int getMaxCl() 
+    size_t getMaxCl() 
     {
 	return m_parentSearch ? m_parentSearch->getMaxCl() : 100000;
     }
@@ -280,13 +282,12 @@ public:
     {
 	return m_parentSearch ? m_parentSearch->getSoftMaxExp() : -1;
     }
-    virtual void setModifiers(Modifier mod) 
-    {
-	m_modifiers = mod;
-    }
     virtual void addModifier(Modifier mod) 
     {
-	m_modifiers = Modifier(m_modifiers | mod);
+	m_modifiers = m_modifiers | mod;
+    }
+    virtual unsigned int getmodifiers() {
+	return m_modifiers;
     }
     virtual void setWeight(float w) 
     {
@@ -314,7 +315,7 @@ protected:
     SClType     m_tp;
     SearchData *m_parentSearch;
     bool        m_haveWildCards;
-    Modifier    m_modifiers;
+    unsigned int  m_modifiers;
     float       m_weight;
     bool        m_exclude;
     Relation    m_rel;
@@ -379,14 +380,15 @@ protected:
     std::string  m_field; // Field specification if any
     HighlightData m_hldata;
     // Current count of Xapian clauses, to check against expansion limit
-    int  m_curcl;
+    size_t  m_curcl;
     bool processUserString(Rcl::Db &db, const string &iq,
 			   std::string &ermsg,
 			   void* pq, int slack = 0, bool useNear = false);
     bool expandTerm(Rcl::Db &db, std::string& ermsg, int mods, 
 		    const std::string& term, 
 		    std::vector<std::string>& exp, 
-                    std::string& sterm, const std::string& prefix);
+                    std::string& sterm, const std::string& prefix,
+		    std::vector<std::string>* multiwords = 0);
     // After splitting entry on whitespace: process non-phrase element
     void processSimpleSpan(Rcl::Db &db, string& ermsg, const string& span, 
 			   int mods, void *pq);
@@ -491,7 +493,7 @@ private:
 /** Subquery */
 class SearchDataClauseSub : public SearchDataClause {
 public:
-    SearchDataClauseSub(RefCntr<SearchData> sub) 
+    SearchDataClauseSub(STD_SHARED_PTR<SearchData> sub) 
 	: SearchDataClause(SCLT_SUB), m_sub(sub) 
     {
     }
@@ -505,15 +507,15 @@ public:
 
     virtual void getTerms(HighlightData& hldata) const
     {
-	m_sub.getconstptr()->getTerms(hldata);
+	m_sub.get()->getTerms(hldata);
     }
-    virtual RefCntr<SearchData> getSub() {
+    virtual STD_SHARED_PTR<SearchData> getSub() {
         return m_sub;
     }
     virtual void dump(ostream& o) const;
 
 protected:
-    RefCntr<SearchData> m_sub;
+    STD_SHARED_PTR<SearchData> m_sub;
 };
 
 } // Namespace Rcl
