@@ -25,6 +25,7 @@
 #include <vector>
 #include <algorithm>
 #include <sstream>
+#include <iostream>
 using namespace std;
 
 #include "xapian.h"
@@ -53,9 +54,10 @@ typedef  vector<SearchDataClause *>::iterator qlist_it_t;
 
 static const int original_term_wqf_booster = 10;
 
-// Expand categories and mime type wild card exps Categories are
-// expanded against the configuration, mimetypes against the index
-// (for wildcards).
+// Expand doc categories and mime type wild card expressions 
+//
+// Categories are expanded against the configuration, mimetypes
+// against the index.
 bool SearchData::expandFileTypes(Db &db, vector<string>& tps)
 {
     const RclConfig *cfg = db.getConf();
@@ -101,6 +103,8 @@ static const char *maxXapClauseCaseDiacMsg =
     "wildcards ?"
     ;
 
+
+// Walk the clauses list, translate each and add to top Xapian Query
 bool SearchData::clausesToQuery(Rcl::Db &db, SClType tp, 
 				vector<SearchDataClause*>& query, 
 				string& reason, void *d)
@@ -164,6 +168,8 @@ bool SearchData::toNativeQuery(Rcl::Db &db, void *d)
 
     db.getConf()->getConfParam("maxTermExpand", &m_maxexp);
     db.getConf()->getConfParam("maxXapianClauses", &m_maxcl);
+    db.getConf()->getConfParam("autocasesens", &m_autocasesens);
+    db.getConf()->getConfParam("autodiacsens", &m_autodiacsens);
 
     // Walk the clause list translating each in turn and building the 
     // Xapian query tree
@@ -215,9 +221,8 @@ bool SearchData::toNativeQuery(Rcl::Db &db, void *d)
 
     if (m_minSize != size_t(-1) || m_maxSize != size_t(-1)) {
         Xapian::Query sq;
-	char min[50], max[50];
-	sprintf(min, "%lld", (long long)m_minSize);
-	sprintf(max, "%lld", (long long)m_maxSize);
+	string min = lltodecstr(m_minSize);
+	string max = lltodecstr(m_maxSize);
 	if (m_minSize == size_t(-1)) {
 	    string value(max);
 	    leftzeropad(value, 12);
@@ -246,7 +251,7 @@ bool SearchData::toNativeQuery(Rcl::Db &db, void *d)
     }
 
     // Add the autophrase if any
-    if (m_autophrase.isNotNull()) {
+    if (m_autophrase) {
 	Xapian::Query apq;
 	if (m_autophrase->toNativeQuery(db, &apq)) {
 	    xq = xq.empty() ? apq : 
@@ -375,17 +380,6 @@ private:
 };
 
 
-#if 1
-static void listVector(const string& what, const vector<string>&l)
-{
-    string a;
-    for (vector<string>::const_iterator it = l.begin(); it != l.end(); it++) {
-        a = a + *it + " ";
-    }
-    LOGDEB0(("%s: %s\n", what.c_str(), a.c_str()));
-}
-#endif
-
 /** Expand term into term list, using appropriate mode: stem, wildcards, 
  *  diacritics... 
  *
@@ -396,12 +390,16 @@ static void listVector(const string& what, const vector<string>&l)
  * @param prefix field prefix in index. We could recompute it, but the caller
  *  has it already. Used in the simple case where there is nothing to expand, 
  *  and we just return the prefixed term (else Db::termMatch deals with it).
+ * @param multiwords it may happen that synonym processing results in multi-word
+ *   expansions which should be processed as phrases.
  */
 bool SearchDataClauseSimple::expandTerm(Rcl::Db &db, 
 					string& ermsg, int mods, 
 					const string& term, 
 					vector<string>& oexp, string &sterm,
-					const string& prefix)
+					const string& prefix,
+					vector<string>* multiwords
+    )
 {
     LOGDEB0(("expandTerm: mods 0x%x fld [%s] trm [%s] lang [%s]\n",
 	     mods, m_field.c_str(), term.c_str(), getStemLang().c_str()));
@@ -432,13 +430,12 @@ bool SearchDataClauseSimple::expandTerm(Rcl::Db &db,
 	nostemexp = true;
     }
 
-    // noexpansion can be modified further down by possible case/diac expansion
-    bool noexpansion = nostemexp && !haswild; 
-
-    int termmatchsens = 0;
-
     bool diac_sensitive = (mods & SDCM_DIACSENS) != 0;
     bool case_sensitive = (mods & SDCM_CASESENS) != 0;
+    bool synonyms = (mods & SDCM_NOSYNS) == 0;
+
+    // noexpansion can be modified further down by possible case/diac expansion
+    bool noexpansion = nostemexp && !haswild && !synonyms; 
 
     if (o_index_stripchars) {
 	diac_sensitive = case_sensitive = false;
@@ -468,31 +465,38 @@ bool SearchDataClauseSimple::expandTerm(Rcl::Db &db,
 
 	// If we are sensitive to case or diacritics turn stemming off
 	if (diac_sensitive || case_sensitive) {
-	    LOGDEB0(("expandTerm: diac or case sens set -> stemexpand off\n"));
+	    LOGDEB0(("expandTerm: diac or case sens set -> "
+                     "stemexpand and synonyms off\n"));
 	    nostemexp = true;
+            synonyms = false;
 	}
 
 	if (!case_sensitive || !diac_sensitive)
 	    noexpansion = false;
     }
 
-    if (case_sensitive)
-	termmatchsens |= Db::ET_CASESENS;
-    if (diac_sensitive)
-	termmatchsens |= Db::ET_DIACSENS;
 
     if (noexpansion) {
 	oexp.push_back(prefix + term);
 	m_hldata.terms[term] = term;
-	LOGDEB(("ExpandTerm: noexpansion: final: %s\n", stringsToString(oexp).c_str()));
+	LOGDEB(("ExpandTerm: noexpansion: final: %s\n", 
+                stringsToString(oexp).c_str()));
 	return true;
     } 
 
+    int termmatchsens = 0;
+    if (case_sensitive)
+	termmatchsens |= Db::ET_CASESENS;
+    if (diac_sensitive)
+	termmatchsens |= Db::ET_DIACSENS;
+    if (synonyms)
+	termmatchsens |= Db::ET_SYNEXP;
+	
     Db::MatchType mtyp = haswild ? Db::ET_WILD : 
 	nostemexp ? Db::ET_NONE : Db::ET_STEM;
     TermMatchResult res;
-    if (!db.termMatch(mtyp | termmatchsens, getStemLang(), term, res, maxexpand,
-		      m_field)) {
+    if (!db.termMatch(mtyp | termmatchsens, getStemLang(), 
+		      term, res, maxexpand,  m_field, multiwords)) {
 	// Let it go through
     }
 
@@ -555,9 +559,17 @@ void multiply_groups(vector<vector<string> >::const_iterator vvit,
     }
 }
 
-void SearchDataClauseSimple::processSimpleSpan(Rcl::Db &db, string& ermsg,
-					       const string& span, 
-					       int mods, void * pq)
+static void prefix_vector(vector<string>& v, const string& prefix)
+{
+    for (vector<string>::iterator it = v.begin(); it != v.end(); it++) {
+	*it = prefix + *it;
+    }
+}
+
+void SearchDataClauseSimple::
+processSimpleSpan(Rcl::Db &db, string& ermsg,
+		  const string& span, 
+		  int mods, void * pq)
 {
     vector<Xapian::Query>& pqueries(*(vector<Xapian::Query>*)pq);
     LOGDEB0(("StringToXapianQ::processSimpleSpan: [%s] mods 0x%x\n",
@@ -568,10 +580,13 @@ void SearchDataClauseSimple::processSimpleSpan(Rcl::Db &db, string& ermsg,
     string prefix;
     const FieldTraits *ftp;
     if (!m_field.empty() && db.fieldToTraits(m_field, &ftp, true)) {
+	if (ftp->noterms)
+	    addModifier(SDCM_NOTERMS); // Don't add terms to highlight data
 	prefix = wrap_prefix(ftp->pfx);
     }
 
-    if (!expandTerm(db, ermsg, mods, span, exp, sterm, prefix))
+    vector<string> multiwords;
+    if (!expandTerm(db, ermsg, mods, span, exp, sterm, prefix, &multiwords))
 	return;
     
     // Set up the highlight data. No prefix should go in there
@@ -601,6 +616,23 @@ void SearchDataClauseSimple::processSimpleSpan(Rcl::Db &db, string& ermsg,
 			   Xapian::Query(prefix+sterm, 
 					 original_term_wqf_booster));
     }
+
+    // Push phrases for the multi-word expansions
+    for (vector<string>::const_iterator mwp = multiwords.begin();
+	 mwp != multiwords.end(); mwp++) {
+	vector<string> phr;
+	// We just do a basic split to keep things a bit simpler here
+	// (no textsplit). This means though that no punctuation is
+	// allowed in multi-word synonyms.
+	stringToTokens(*mwp, phr);
+	if (!prefix.empty())
+	    prefix_vector(phr, prefix);
+	xq = Xapian::Query(Xapian::Query::OP_OR, xq, 
+			   Xapian::Query(Xapian::Query::OP_PHRASE, 
+					 phr.begin(), phr.end()));
+	m_curcl++;
+    }
+
     pqueries.push_back(xq);
 }
 
@@ -653,8 +685,8 @@ void SearchDataClauseSimple::processPhraseOrNear(Rcl::Db &db, string& ermsg,
 	vector<string> exp;
 	if (!expandTerm(db, ermsg, lmods, *it, exp, sterm, prefix))
 	    return;
-	LOGDEB0(("ProcessPhraseOrNear: exp size %d\n", exp.size()));
-	listVector("", exp);
+	LOGDEB0(("ProcessPhraseOrNear: exp size %d, exp: %s\n", exp.size(),
+		 stringsToString(exp).c_str()));
 	// groups is used for highlighting, we don't want prefixes in there.
 	vector<string> noprefs;
 	for (vector<string>::const_iterator it = exp.begin(); 
@@ -809,7 +841,7 @@ bool SearchDataClauseSimple::processUserString(Rcl::Db &db, const string &iq,
 	    tpq.setTSQ(&splitter);
 	    splitter.text_to_words(*it);
 
-	    slack += tpq.lastpos() - tpq.terms().size() + 1;
+	    slack += tpq.lastpos() - int(tpq.terms().size()) + 1;
 
 	    LOGDEB0(("strToXapianQ: termcount: %d\n", tpq.terms().size()));
 	    switch (tpq.terms().size() + terminc) {
@@ -932,7 +964,7 @@ bool SearchDataClausePath::toNativeQuery(Rcl::Db &db, void *p)
 
     vector<Xapian::Query> orqueries;
 
-    if (m_text[0] == '/')
+    if (path_isabsolute(m_text))
 	orqueries.push_back(Xapian::Query(wrap_prefix(pathelt_prefix)));
     else
         m_text = path_tildexpand(m_text);
@@ -950,8 +982,8 @@ bool SearchDataClausePath::toNativeQuery(Rcl::Db &db, void *p)
 			*pit, exp, sterm, wrap_prefix(pathelt_prefix))) {
 	    return false;
 	}
-	LOGDEB0(("SDataPath::toNative: exp size %d\n", exp.size()));
-	listVector("", exp);
+	LOGDEB0(("SDataPath::toNative: exp size %d. Exp: %s\n", exp.size(),
+		 stringsToString(exp).c_str()));
 	if (exp.size() == 1)
 	    orqueries.push_back(Xapian::Query(exp[0]));
 	else 
