@@ -15,14 +15,19 @@
  *   59 Temple Place - Suite 330, Boston, MA  02111-1307, USA.
  */
 #ifndef TEST_COPYFILE
+#include "autoconfig.h"
+
 #include <stdio.h>
-#include <fcntl.h>
 #include <errno.h>
-#include <unistd.h>
+#include "safefcntl.h"
 #include <sys/types.h>
-#include <sys/stat.h>
+#include "safesysstat.h"
+#include "safeunistd.h"
+#ifndef _WIN32
 #include <sys/time.h>
 #include <utime.h>
+#define O_BINARY 0
+#endif
 
 #include <cstring>
 
@@ -39,11 +44,11 @@ bool copyfile(const char *src, const char *dst, string &reason, int flags)
     int dfd = -1;
     bool ret = false;
     char buf[CPBSIZ];
-    int oflags = O_WRONLY|O_CREAT|O_TRUNC;
+    int oflags = O_WRONLY|O_CREAT|O_TRUNC|O_BINARY;
 
     LOGDEB(("copyfile: %s to %s\n", src, dst));
 
-    if ((sfd = ::open(src, O_RDONLY)) < 0) {
+    if ((sfd = ::open(src, O_RDONLY, 0)) < 0) {
         reason += string("open ") + src + ": " + strerror(errno);
         goto out;
     }
@@ -92,7 +97,7 @@ bool stringtofile(const string& dt, const char *dst, string& reason,
     LOGDEB(("stringtofile:\n"));
     int dfd = -1;
     bool ret = false;
-    int oflags = O_WRONLY|O_CREAT|O_TRUNC;
+    int oflags = O_WRONLY|O_CREAT|O_TRUNC|O_BINARY;
 
     LOGDEB(("stringtofile: %u bytes to %s\n", (unsigned int)dt.size(), dst));
 
@@ -149,6 +154,7 @@ bool renameormove(const char *src, const char *dst, string &reason)
         return false;
     }
 
+#ifndef _WIN32
     // Try to preserve modes, owner, times. This may fail for a number
     // of reasons
     if ((st1.st_mode & 0777) != (st.st_mode & 0777)) {
@@ -167,7 +173,7 @@ bool renameormove(const char *src, const char *dst, string &reason)
     times[1].tv_sec = st.st_mtime;
     times[1].tv_usec = 0;
     utimes(dst, times);
-
+#endif
     // All ok, get rid of origin
     if (unlink(src) < 0) {
         reason += string("Can't unlink ") + src + "Error : " + strerror(errno);
