@@ -21,8 +21,8 @@
 #include <stdarg.h>
 #include <stdlib.h>
 #include <string.h>
-#include <fcntl.h>
-
+#include <errno.h>
+#include <safefcntl.h> // in case O_APPEND is in there
 #ifdef INCLUDE_NEW_H
 #include <new.h>
 #endif
@@ -41,12 +41,9 @@ using std::string;
 #define freeZ(X) {if (X) {free(X);X=0;}}
 #endif
 
-#ifndef NO_NAMESPACES
 using namespace std;
 namespace DebugLog {
 
-#endif // NO_NAMESPACES
-
 bool DebugLog::isspecialname(const char *logname) 
 {
     return !strcmp(logname, "stdout") || !strcmp(logname, "stderr");
@@ -76,15 +73,18 @@ class DLFWImpl {
 	} else {
 	    fp = fopen(filename, (truncate) ? "w" : "a");
 	    if (fp) {
-		setvbuf(fp, 0, _IOLBF, 0);
-#ifdef O_APPEND
+		setvbuf(fp, 0, _IOLBF, BUFSIZ);
+#if defined(O_APPEND) && !defined(_WIN32)
 		{
 		    int flgs = 0;
 		    fcntl(fileno(fp), F_GETFL, &flgs);
 		    fcntl(fileno(fp), F_SETFL, flgs|O_APPEND);
 		}
 #endif
-	    }
+	    } else {
+                fprintf(stderr, "Debuglog: could not open [%s] errno %d\n",
+                        filename, errno);
+            }
 	}
 	return;
     }
@@ -193,7 +193,7 @@ static bool fileInFiles(const string& file)
     return false;
 }
 
-#ifdef _WINDOWS
+#ifdef _WIN32
 #include <windows.h>
 static void datestring(char *d, int sz) {
     SYSTEMTIME buf;
@@ -390,16 +390,19 @@ DebugLog *getdbl()
 }
 #endif
 
-#ifndef NO_NAMESPACES
 }
-#endif // NO_NAMESPACES
 
 ////////////////////////////////////////// TEST DRIVER //////////////////
 #else /* TEST_DEBUGLOG */
 
 #include <stdio.h>
 #include <stdlib.h>
+#ifdef _WIN32
+#include <windows.h>
+static inline unsigned int sleep(unsigned int s) {Sleep(s * 1000); return 0;}
+#else
 #include <unistd.h>
+#endif
 #include <string.h>
 
 #include "debuglog.h"
