@@ -14,17 +14,16 @@
  *   Free Software Foundation, Inc.,
  *   59 Temple Place - Suite 330, Boston, MA  02111-1307, USA.
  */
-#ifdef HAVE_CONFIG_H
+
 #include "autoconfig.h"
-#endif
 
 #ifndef TEST_FSTREEWALK
 
 #include <stdio.h>
 #include <dirent.h>
-#include <sys/stat.h>
 #include <errno.h>
 #include <fnmatch.h>
+#include "safesysstat.h"
 #include <cstring>
 #include <algorithm>
 
@@ -38,15 +37,16 @@
 #include "pathut.h"
 #include "fstreewalk.h"
 
-#ifndef NO_NAMESPACES
 using namespace std;
-#endif /* NO_NAMESPACES */
 
 bool FsTreeWalker::o_useFnmPathname = true;
 
 const int FsTreeWalker::FtwTravMask = FtwTravNatural|
     FtwTravBreadth|FtwTravFilesThenDirs|FtwTravBreadthThenDepth;
 
+#ifndef _WIN32
+// dev/ino means nothing on Windows. It seems that FileId could replace it
+// but we only use this for cycle detection which we just disable.
 class DirId {
 public:
     dev_t dev;
@@ -57,6 +57,7 @@ public:
 	return dev < r.dev || (dev == r.dev && ino < r.ino);
     }
 };
+#endif
 
 class FsTreeWalker::Internal {
 public:
@@ -75,7 +76,9 @@ public:
     // of directory paths to be processed, and we do not recurse.
     deque<string> dirs;
     int errors;
+#ifndef _WIN32
     set<DirId> donedirs;
+#endif
     void logsyserr(const char *call, const string &param) 
     {
 	errors++;
@@ -222,7 +225,7 @@ FsTreeWalker::Status FsTreeWalker::walk(const string& _top,
     data->basedepth = slashcount(top); // Only used for breadthxx
     struct stat st;
     // We always follow symlinks at this point. Makes more sense.
-    if (stat(top.c_str(), &st) == -1) {
+    if (path_fileprops(top, &st) == -1) {
 	// Note that we do not return an error if the stat call
 	// fails. A temp file may have gone away.
 	data->logsyserr("stat", top);
@@ -284,7 +287,7 @@ FsTreeWalker::Status FsTreeWalker::walk(const string& _top,
 
         // If changing parent directory, advise our user.
         if (!nfather.empty()) {
-            if (stat(nfather.c_str(), &st) == -1) {
+            if (path_fileprops(nfather, &st) == -1) {
                 data->logsyserr("stat", nfather);
 		return errno == ENOENT ? FtwOk : FtwError;
             }
@@ -294,7 +297,7 @@ FsTreeWalker::Status FsTreeWalker::walk(const string& _top,
             }
         }
 
-        if (stat(dir.c_str(), &st) == -1) {
+        if (path_fileprops(dir, &st) == -1) {
             data->logsyserr("stat", dir);
 	    return errno == ENOENT ? FtwOk : FtwError;
         }
@@ -344,6 +347,7 @@ FsTreeWalker::Status FsTreeWalker::iwalk(const string &top,
     // no point in entering again.
     // For now, we'll ignore the "other kind of cycle" part and only monitor
     // this is FtwFollow is set
+#ifndef _WIN32
     if (data->options & FtwFollow) {
 	DirId dirid(stp->st_dev, stp->st_ino);
 	if (data->donedirs.find(dirid) != data->donedirs.end()) {
@@ -353,7 +357,8 @@ FsTreeWalker::Status FsTreeWalker::iwalk(const string &top,
 	}
 	data->donedirs.insert(dirid);
     }
-
+#endif
+    
     DIR *d = opendir(top.c_str());
     if (d == 0) {
 	data->logsyserr("opendir", top);
@@ -361,6 +366,10 @@ FsTreeWalker::Status FsTreeWalker::iwalk(const string &top,
 	case EPERM:
 	case EACCES:
 	case ENOENT:
+#ifdef _WIN32
+            // We get this quite a lot, don't know why. To be checked.
+        case EINVAL:
+#endif
 	    goto out;
 	default:
 	    status = FtwError;
@@ -386,12 +395,25 @@ FsTreeWalker::Status FsTreeWalker::iwalk(const string &top,
 	}
 
         fn = path_cat(top, ent->d_name);
-        int statret = (data->options & FtwFollow) ? stat(fn.c_str(), &st) :
-            lstat(fn.c_str(), &st);
+#ifdef _WIN32
+        // readdir gets the useful attrs, no inode indirection on windows,
+        // spare the path_fileprops() call, but make sure we mimick it.
+        memset(&st, 0, sizeof(st));
+        st.st_mtime = ent->d_mtime;
+        st.st_size = ent->d_size;
+        st.st_mode = ent->d_mode;
+        // ctime is really creation time on Windows. Just use mtime
+        // for all. We only use ctime on Unix to catch xattr changes
+        // anyway.
+        st.st_ctime = st.st_mtime;
+#else
+        int statret =  path_fileprops(fn.c_str(), &st, data->options&FtwFollow);
         if (statret == -1) {
             data->logsyserr("stat", fn);
             continue;
         }
+#endif
+
         if (!data->skippedPaths.empty()) {
             // We do not check the ancestors. This means that you can have
             // a topdirs member under a skippedPath, to index a portion of
