@@ -49,7 +49,7 @@ public:
      *    meaning no limit. hi == -1 means that the queue is disabled.
      * @param lo minimum count of tasks before worker starts. Default 1.
      */
-    WorkQueue(const string& name, size_t hi = 0, size_t lo = 1)
+    WorkQueue(const std::string& name, size_t hi = 0, size_t lo = 1)
         : m_name(name), m_high(hi), m_low(lo),
           m_workers_exited(0), m_clients_waiting(0), m_workers_waiting(0), 
 	  m_tottasks(0), m_nowake(0), m_workersleeps(0), m_clientsleeps(0)
@@ -309,7 +309,7 @@ private:
     }
 
     // Configuration
-    string m_name;
+    std::string m_name;
     size_t m_high;
     size_t m_low; 
 
